<?php
/** 
 * SEO
 * 
 * Lets the user set specific SEO Options
 */

global $clf_base_load_backend;
if($clf_base_load_backend)
	require_once("panel.php");
	
	
	
add_action('init', 'clf_base_seo_options_init'); /* adds the layout styles to the theme */

/**
 * clf_base_seo_options_init function.
 * 
 * @access public
 * @return void
 */
function clf_base_seo_options_init() {
	global $clf_base_options;
	if(!is_admin()):
		/* web master sites intergration */
		if(isset($clf_base_options['seo']['google-webmaster']['code']) && $clf_base_options['seo']['google-webmaster']['code'] != '')
			add_action("hybrid_head","clf_base_seo_google_webmaster_meta");
		if(isset($clf_base_options['seo']['bing-webmaster']['code']) && $clf_base_options['seo']['bing-webmaster']['code'] != '')
			add_action("hybrid_head","clf_base_seo_bing_webmaster_meta");	
			
		if(isset($clf_base_options['seo']['yahoo-site-explorer']['code']) && $clf_base_options['seo']['yahoo-site-explorer']['code'] != '')
			add_action("hybrid_head","clf_base_seo_yahoo_site_explorer_meta");	
		
		add_filter('hybrid_document_title','clf_base_document_title');
		add_filter('hybrid_meta_description','clf_base_meta_description');
	endif;
		
	// set the stuff per page
}


/* web master sites intergration */
function clf_base_seo_google_webmaster_meta() {
	global $clf_base_options;
	echo "<meta name=\"google-site-verification\" content=\"".esc_attr($clf_base_options['seo']['google-webmaster']['code'])."\" />\n";
}
function clf_base_seo_bing_webmaster_meta() {
	global $clf_base_options;
	echo "<meta name=\"msvalidate.01\" content=\"".esc_attr($clf_base_options['seo']['bing-webmaster']['code'])."\" />\n";
}
function clf_base_seo_yahoo_site_explorer_meta() {
	global $clf_base_options;
	echo "<meta name=\"y_key\" content=\"".esc_attr($clf_base_options['seo']['yahoo-site-explorer']['code'])."\" />\n";
}


function clf_base_document_title($title)
{
	global $clf_base_options, $post, $wp_query;
	
	if(isset($clf_base_options['seo']['frontpage']['title']) && $clf_base_options['seo']['frontpage']['title'] != '' && is_front_page())
		return $clf_base_options['seo']['frontpage']['title'];
	
	if(is_singular() && !is_attachment() )
		return clf_base_get_document_title($post->ID);
	
	return $title;
}

function clf_base_meta_description($description)
{
	global $clf_base_options, $post, $wp_query;
	
	if(isset($clf_base_options['seo']['frontpage']['meta-description']) && $clf_base_options['seo']['frontpage']['meta-description'] != '' && is_home())
		return '<meta name="description" content="' . str_replace( array( "\r", "\n", "\t" ), '', esc_attr( strip_tags($clf_base_options['seo']['frontpage']['meta-description']) ) ). '" />' . "\n";
	
	if(is_singular() && !is_attachment())
		return clf_base_get_document_description($post);
	
	return $title;

}

function clf_base_get_document_title($post_id,$over_ride = null)
{
	global $wp_query,$clf_base_options;
	$title = get_the_title($post_id);
	$site_name = get_bloginfo('name');
	$doctitle  = '';
	
	if(!is_null($over_ride)):
		$doctitle =  $over_ride;
	endif;
	
	if($doctitle == '' ):
	
		if(isset($clf_base_options['seo']['default']['title']) && $clf_base_options['seo']['default']['title'] !=""):
			$doctitle = str_replace(array('%page_or_post_title%','%sitename%') ,array($title,$site_name) , $clf_base_options['seo']['default']['title']);
		else:
			$doctitle =  $title. " | " . $site_name;
		endif;
	endif;	
	
	
	/* If paged. */
	if ( ( ( $page = $wp_query->get( 'paged' ) ) || ( $page = $wp_query->get( 'page' ) ) ) && $page > 1 )
		$doctitle = sprintf( __('%1$s Page %2$s', 'hybrid'), $doctitle . $separator, $page );
		
	return esc_html($doctitle);
}


function clf_base_get_document_description($post, $over_ride = null)
{
	global $post;
	
	// setup_postdata($post);
	$description = get_the_excerpt();
	// get_post_meta( $post->ID, 'Description', true );
	if( get_post_meta( $post->ID, 'Description', true ) != '')
		$description = wp_specialchars( get_post_meta( $post->ID, 'Description', true ), true );
	
	if($description != "")
	return '<meta name="description" content="' . str_replace( array( "\r", "\n", "\t" ), '', esc_attr( strip_tags($description) ) ). '" />' . "\n";
	else
		return "";
}



