<?php 
/** 
 * SEO
 *
 */
add_action('admin_init', 'clf_base_seo');


/**
 * clf_base_frontpage function.
 * 
 * @access public
 * @return void
 */
function clf_base_seo() {
	add_settings_section('seo', 'SEO', 'clf_base_theme_options_seo', 'clf-base-theme-options');
	add_settings_field('clf-base-seo-options', 'SEO Options', 'clf_base_theme_options_seo_options', 'clf-base-theme-options', 'seo');
	add_settings_field('clf-base-google-sitemaster-options', 'Google Webmaster', 'clf_base_theme_options_google_sitemaster', 'clf-base-theme-options', 'seo');
	add_settings_field('clf-base-bing-sitemaster-options', 'Bing Webmaster', 'clf_base_theme_options_bing_sitemaster', 'clf-base-theme-options', 'seo');
	add_settings_field('clf-base-yahoo-sitemaster-options', 'Yahoo Site Explorer', 'clf_base_theme_options_yahoo_sitemaster', 'clf-base-theme-options', 'seo');
	add_settings_field('clf-base-seo-resources', 'SEO Resources', 'clf_base_theme_options_seo_resources', 'clf-base-theme-options', 'seo');
	
	add_action('clf_base_admin_ui','clf_base_clf_seo_styles');
	// Styles for the UBC Header Panel
	wp_register_style('clf-base-css-ui-seo', get_bloginfo('stylesheet_directory').'/library/SEO/panel.css');
}

function clf_base_clf_seo_styles()
{
	wp_enqueue_style( 'clf-base-css-ui-seo');

}

function clf_base_theme_options_seo()
{
	if(get_option('blog_public') < 1):
		echo "<p class='error'><strong >SEO Issue:</strong> Your site visibility is set to <strong>Blocked Search Engines</strong>. <a href='".admin_url('options-privacy.php')."'>change site visibility</a></p>";
	else:
		echo "<p class='info'>Great, your site is indexable by search engines</p>";
	endif;
}

function clf_base_theme_options_seo_options()
{
	global $clf_base_options;
	
	$date_format = get_option('date_format');
		
	?>
	<div class="clear">
		<div class="explanation">
		<h3>Frontpage SEO Options</h3>
		<p>Control what is displayed in the HTML &lt;title&gt; tag.</p>
		</div>
	</div>
	<div>
		<label for="seo-fontpage-title">Frontpage HTML &lt;title&gt;:</label><br />
		<input id="seo-fontpage-title" type="text" class="text" name="clf_base[seo][frontpage][title]" value="<?php echo $clf_base_options['seo']['frontpage']['title']; ?>" /><br />
		<span>if empty: <strong><?php bloginfo('name'); ?>: <?php bloginfo('description'); ?></strong></span><br />
		<label for="seo-fontpage-meta-description">Frontpage Meta Description:</label><br />
		<textarea id="seo-fontpage-meta-description" cols="70" name="clf_base[seo][frontpage][meta-description]"><?php 
		if( isset( $clf_base_options['seo']['frontpage']['meta-description'] ) )
			echo $clf_base_options['seo']['frontpage']['meta-description']; 
		
		?></textarea><br />
		<span>if empty: <strong><?php bloginfo('description'); ?></strong></span>
	</div>
	<!-- HTML title -->
	<div class="clear">
		<div class="explanation">
		<h3>HTML &lt;title&gt; Default Template</h3>
		<p>Control what is displayed in the HTML &lt;title&gt; tag by default</p>
		<p>%page_or_post_title% - the post or page title</p> 
			<p>%sitename% - the name of the site: <strong><?php bloginfo('name'); ?></strong> - You can change this under <em>Settings &gt; <a target="_blank" href="<?php admin_url('/wp-admin/options-general.php'); ?>">General</a></em></p>
		</div>
	</div>
	<div id="post-byline-options" >
		<div>
			<label for="seo-default-title">HTML &lt;title&gt; Default Template:</label><br />
			<textarea  id="seo-default-title" cols="70" name="clf_base[seo][default][title]"><?php 
			if( isset($clf_base_options['seo']['default']['title']) )
				echo $clf_base_options['seo']['default']['title']; 
			?></textarea> <br />
			
			<span>if empty: &lt;title&gt; <strong>%page_or_post_title% | %sitename%</strong> &lt;/title&gt;</span>
		</div>
	</div>
	
	
	
	
	<div class="clear">
		<div class="explanation">
		<h3>Enable Page and Post Specific SEO Options</h3>
		<p>Control what is displayed in the HTML &lt;title&gt; per page and post. </p>
		</div>
		<label><input type="checkbox" name="clf_base[seo][page][enable]" value="1" <?php checked( isset($clf_base_options['seo']['page']['enable'])); ?> > Page Specific SEO Options</label><br />
		<label><input type="checkbox" name="clf_base[seo][post][enable]" value="1" <?php checked( isset($clf_base_options['seo']['post']['enable'])); ?> > Post Specific SEO Options</label>
	</div>
	<?php 

}

function clf_base_theme_options_google_sitemaster()
{
	// <meta name="google-site-verification" content="" />
	global $clf_base_options;
	?>
		<div class="clear">
			<div class="explanation">
				<h3>Google Webmaster verification code</h3>
				<p>A place to enter your <a href="http://www.google.com/webmasters/" target="_blank">google webmaster</a> verification code to check how your site is doing on google. 
				
				Once you place your code leave it in there to stay verified with google webmaster. </p>
				<p>If you enter text in this box, a meta tag will be enabled.  </p>
			</div>
		<label>&lt;meta name="google-site-verification" content="</label><input id="google-webmaster-code" type="text" class="text" name="clf_base[seo][google-webmaster][code]" value="<?php echo $clf_base_options['seo']['google-webmaster']['code']; ?>"  />" /&gt;<br />
		
	</div>
	<?php 
}

function clf_base_theme_options_bing_sitemaster()
{
	// <meta name="msvalidate.01" content="" />
	global $clf_base_options;
	?>
		<div class="clear">
			<div class="explanation">
				<h3>Bing Webmaster verification code</h3>
				<p>A place to enter your <a href="http://www.bing.com/webmaster" target="_blank">bing webmaster</a> verification code to check how your site is doing on bing. 
				
				Once you place your code leave it in there to stay verified with bing webmaster. </p>
				<p>If you enter text in this box, a meta tag will be enabled.  </p>
			</div>
		<label>&lt;meta name="msvalidate.01" content="</label><input id="bing-webmaster-code" type="text" class="text" name="clf_base[seo][bing-webmaster][code]" value="<?php echo $clf_base_options['seo']['bing-webmaster']['code']; ?>"  />" /&gt;<br />
	</div>
	<?php 
}

function clf_base_theme_options_yahoo_sitemaster()
{
	// <meta name="y_key" content="" />
	global $clf_base_options;
	?>
		<div class="clear">
			<div class="explanation">
				<h3>Yahoo site explorer verification code</h3>
				<p>A place to enter your <a href="http://siteexplorer.search.yahoo.com" target="_blank">Yahoo site explorer</a> verification code to check how your site is doing on yahoo. 
				
				Once you place your code leave it in there to stay verified with Yahoo site explorer. </p>
				<p>If you enter text in this box, a meta tag will be enabled.  </p>
			</div>
		<label>&lt;meta name="y_key" content="</label><input id="yahoo-site-explorer-code" type="text" class="text" name="clf_base[seo][yahoo-site-explorer][code]" value="<?php echo $clf_base_options['seo']['yahoo-site-explorer']['code']; ?>"  />" /&gt;<br />
	</div>
	<?php 
}

function clf_base_theme_options_seo_resources()
{
	?>
	<div class="half">
		<ul>
			<li>Google</li>
			<li><a href="http://www.google.com/webmasters" target="_blank">Google webmaster central</a></li>
			<li><a href="http://googlewebmastercentral.blogspot.com/2008/11/googles-seo-starter-guide.html" target="_blank">Google's SEO Starter Guide</a></li>
			<li><a href="http://www.google.com/insights/search/#q=&cmpt=q" target="_blank">Google Insights for Search</a></li>
			<li><a href="https://adwords.google.com/o/Targeting/Explorer?__u=1000000000&__c=1000000000&ideaRequestType=KEYWORD_IDEAS#search.none">Google Adwords: Keyword Tool</a></li>
		</ul>
		
		
	</div>
	<div class="half">
		
	</div>
	
	<?php 
}


/**
 * SEO CUSTOM FIELDS META BOX 
 *************************************/
 
global $clf_base_options;
/* add the meta box functionality */
if( $clf_base_options['seo']['page']['enable'] || $clf_base_options['seo']['post']['enable']):
	/* Use the admin_menu action to define the custom boxes */
	add_action( 'admin_menu', 'clf_base_seo_custom_box' );
	/* Use the save_post action to do something with the data entered */
	add_action( 'save_post', 'clf_base_seo_custom_box_save');
	
	
	add_action( 'admin_print_scripts-post-new.php', 'clf_base_seo_post_page_init_script' );
	add_action( 'admin_print_styles-post-new.php', 'clf_base_seo_post_page_init_style' );
	
	add_action( 'admin_print_scripts-post.php', 'clf_base_seo_post_page_init_script' );
	add_action( 'admin_print_styles-post.php', 'clf_base_seo_post_page_init_style' );

	
endif;

function clf_base_seo_post_page_init_script()
{
	wp_enqueue_script( 'clf-base-seo', get_stylesheet_directory_uri().'/library/SEO/post_page.js','jquery');
}
function clf_base_seo_post_page_init_style()
{
	wp_enqueue_style( 'clf-base-seo', get_stylesheet_directory_uri().'/library/SEO/post_page.css');
}
/* Adds a custom section to the "advanced" Post and Page edit screens */
function clf_base_seo_custom_box() {

	global $clf_base_options;
	if( $clf_base_options['seo']['page']['enable'])
		add_meta_box( 'clf_base_seo_custom_box', __( 'SEO', 'clf_base' ), 'clf_base_soe_custom_box_inner', 'page', 'advanced','low' );
	
	if( $clf_base_options['seo']['post']['enable'])
		add_meta_box( 'clf_base_seo_custom_box', __( 'SEO', 'clf_base' ), 'clf_base_soe_custom_box_inner', 'post', 'advanced','low' );
}



function clf_base_soe_custom_box_inner()
{
   global $post;
  
   $clf_base_seo_title = get_post_meta($post->ID, 'Title', true);
   $clf_base_seo_desci = get_post_meta($post->ID, 'Description', true);
   
   $clf_base_seo_title_remain = (69 - strlen($clf_base_seo_title));
   $clf_base_seo_desci_remain = (156 - strlen($clf_base_seo_desci));
   
   $title_lenght = (strlen($clf_base_seo_title) <70 ? "<span class='good'>".$clf_base_seo_title_remain ."</span>":"<span class='not-good'>".strlen($clf_base_seo_title)."</span>");
   $description_lenght =   (strlen($clf_base_seo_desci) <156 ? "<span class='good'>". $clf_base_seo_desci_remain ."</span>":"<span class='not-good'>".strlen($clf_base_seo_desci)."</span>");
   $clf_base_permission =  $clf_base_permission_a[0];

   // Use nonce for verification
   echo '<input type="hidden" name="clf_base_seo_custom_box_noncename" id="clf_base_seo_custom_box_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
   // The actual fields for data entry
  ?><div id="clf_base_seo_custom_box">
  	<div<table class="form-table">
		<tbody>
			<tr>
			<th scope="row"><label for="clf_base_seo_title">SEO Title:</label></th>
			<td>
			<input type="text" class="large-text" value="<?php echo $clf_base_seo_title; ?>" name="clf_base_seo_title" id="clf_base_seo_title"><br />
			<p>Title display in search engines is limited to 69 chars, <span id="clf_base_seo_title-length"><?php echo $title_lenght; ?></span> chars left.<br />
			If the SEO Title is empty the default SEO template will be used: <strong><?php echo clf_base_get_document_title($post->ID); ?></strong></p>
			<div class="default"><?php echo get_the_title($post->ID); ?> - </div>
			</td>
			</tr>
			
			<tr>
			<th scope="row"><label for="clf_base_seo_metadesc">Meta Description:</label></th>
			<td>
			<textarea name="clf_base_seo_metadesc" id="clf_base_seo_metadesc" rows="3" class="large-text"><?php echo $clf_base_seo_desci; ?></textarea>
			<p>The <code>meta</code> description will be limited to 156 chars, <span id="clf_base_seo_metadesc-length"> <?php echo $description_lenght; ?></span> chars left. 
			
			<?php if(post_type_supports($post->post_type,'excerpt' )): ?>
				If the Meta Description is empty then the excerpt will be used.</p>
			<?php else: ?>
				If the Meta Description is empty then nothing will be display.</p>
			<?php endif; ?>
		
			<div class="default"><?php echo get_the_excerpt(); ?></div>
			</td>
			</tr>
			<tr><th scope="row">Snippet Preview:</th>
			<td>
				<div id="snippet" style="display: block;">
				<a href="#" class="title" id="clf_base_seo_title_snippet"><?php echo clf_base_get_document_title($post->id,$clf_base_seo_title); ?></a>
				<p  class="desc" id="clf_base_seo_metadesc_snippet"><?php echo clf_base_get_document_description($post); ?></p>
				<a class="url" style="font-size: 13px; color: #282; line-height: 15px;" href="#"><strong><?php echo str_replace(array('http://','https://') ,array("","") ,get_permalink($post->ID)); ?></strong></a> - <a class="util" href="#">Cached</a> - <a class="util" href="#">Similar</a>
			</div>
			</td></tr>	
	</tbody></table>
  	</div>
  <?php

}


function clf_base_seo_custom_box_save($post_id)
{
	
	if ( !wp_verify_nonce( $_POST['clf_base_seo_custom_box_noncename'], plugin_basename(__FILE__) )) {
			return $post_id;
	}
	
	// verify if this is an auto save routine. If it is our form has not been submitted, so we dont want
	// to do anything
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
		return $post_id;
	
	$data_description = $_POST['clf_base_seo_metadesc'];
	$data_title = 		$_POST['clf_base_seo_title'];
	
	// description 
	if(get_post_meta($post_id, 'Title') == "")  
		add_post_meta($post_id, 'Title', $data_title, true);  
	
	elseif($data_title != get_post_meta($post_id, 'Title', true))  
		update_post_meta($post_id, 'Title', $data_title);
	
	
	// description 
	if(get_post_meta($post_id, 'Description') == "")  
		add_post_meta($post_id, 'Description', $data_description, true);  
	
	elseif($data_description != get_post_meta($post_id, 'Description', true))  
		update_post_meta($post_id, 'Description', $data_description);
		
	return $post_id;
	/**/
}