<?php
include("lib/GIFEncoder.class.php");

if(!class_exists('ClfBaseCLFGenerator')) :
class ClfBaseCLFGenerator 
{
	// global variables 
	private $ubc_blue = '#002859';
	private $ubc_grey = '#7491a3';
	private $white = '#ffffff';
	
	// the items used everywhere
	public $umbrella_name 	= 'The University of British Columbia';
	public $unit_name 		= 'UBC Sites';
	public $unit_type 		= 'faculty';
	public $images_url 			= null; 
	public $color_id 			= '1';
	public $pom_color			= '#ff0099';
	
	// File 
	private $image_library_path = null;
	private $font_file			= null; 
	private $images_directory 	= null; 
	private $color_options      = array();

	
	/**
	 * ClfBaseCLFGenerator function.
	 * the init function 
	 *
	 * $input is the $clf_base_options['clf_header']
	 * $input['option'];
	 * $input['hexcode'];
	 * $input['umbrella_name'];
	 * $input['unit_name'];
	 *
	 * @access public
	 * @param mixed $input
	 * @return void
	 */
	 
	function ClfBaseCLFGenerator($input)
	{
		$this->umbrella_name = $input['umbrella_name'];
		$this->unit_name	 = $input['unit_name'];
		$this->unit_type 	 = ( trim(strtolower($input['umbrella_name'])) == 'the university of british columbia' ? 'faculty': 'academic');
		$this->color_id		 = $input['option'];
		$this->pom_color	 = $input['hexcode'];
		$this->location 	 = $input['location'];
		
		$this->color_options = array(
			'1' => array(
				'font' => $this->white,
				'background' => $this->ubc_blue,
				'pom' => $this->ubc_blue,
			),
			'2' => array(
				'font' => $this->ubc_blue,
				'background' => $this->white,
				'pom' => $this->ubc_blue,
			),
			'3' => array(
				'font' => $this->white,
				'background' => $this->ubc_grey,
				'pom' => $this->ubc_grey,
			),
			'4' => array(
				'font' => $this->ubc_grey,
				'background' => $this->white,
				'pom' => $this->ubc_grey,
			),
			'5' => array(
				'font' => $this->white,
				'background' => $this->ubc_grey,
				'pom' => "#".$input['hexcode'],
			),
			'6' => array(
				'font' => $this->ubc_grey,
				'background' => $this->white,
				'pom' => "#".$input['hexcode'],
			)
		);
		
		$this->colors 		 = $this->color_options[$input['option']];
		
		$upload_directory = wp_upload_dir();
		
		$this->images_directory 	= $upload_directory['basedir']."/clf_base/clf-header/";
		$this->images_url 			= $upload_directory['baseurl']."/clf_base/clf-header/";
		$this->stylesheet_directory = str_replace("https://", "http://", get_bloginfo('stylesheet_directory'));
		$this->image_library_path 	= STYLESHEETPATH."/library/clf-header/generator/lib/";
		$this->font_file			= STYLESHEETPATH."/library/clf-header/generator/wb.ttf";
		/* create the images path directory */ 
		
		if( !file_exists( $this->images_directory ) ):
			
			if( !file_exists( $upload_directory['baseurl'] ) )
					mkdir( $upload_directory['baseurl'] ); 
			
			if( !file_exists( $upload_directory['baseurl']."/clf_base/" ) )
				mkdir( $upload_directory['baseurl']."/clf_base/" ); 
				
				
			mkdir( $this->images_directory , 0775 ,true); 
		endif;
		
	}
	
	/**
	 * get_dip function.
	 * 
	 * @access public
	 * @param mixed $font
	 * @param mixed $size
	 * @return void
	 */
	function get_dip($font,$size)
	{
		$test_chars = 'abcdefghijklmnopqrstuvwxyz' .
			      'ABCDEFGHIJKLMNOPQRSTUVWXYZ' .
				  '1234567890' .
				  '!@#$%^&*()\'"\\/;.,`~<>[]{}-+_-=' ;
		$box = @ImageTTFBBox($size,0,$font,$test_chars) ;
		return $box[3];
	}
	/**
	 * hex_to_rgb function.
	 * 
	 * @access public
	 * @param mixed $hex
	 * @return void
	 */
	function hex_to_rgb($hex)
	{
	    // remove '#'
	    if(substr($hex,0,1) == '#')
	        $hex = substr($hex,1) ;
	
	    // expand short form ('fff') color
	    if(strlen($hex) == 3):
	        $hex = substr($hex,0,1) . substr($hex,0,1) .
	               substr($hex,1,1) . substr($hex,1,1) .
	               substr($hex,2,1) . substr($hex,2,1) ;
	    endif;
	
	    if(strlen($hex) != 6)
	        return 'Error: Invalid color "'.$hex.'"';
		
		
	    // convert
	    $rgb['red'] = hexdec(substr($hex,0,2)) ;
	    $rgb['green'] = hexdec(substr($hex,2,2)) ;
	    $rgb['blue'] = hexdec(substr($hex,4,2)) ;
		
	    return $rgb ;
	}
	function generate_header_images()
	{
		$this->generate_umbrella_image();
		$this->generate_unit_image();
		$this->generate_place_of_mind();
	}
	/**
	 * generate_umbrella_image function.
	 * 
	 * @access public
	 * @return void
	 */
	private function generate_umbrella_image() {
		
		// Basic Image Parameters
		$width = 379;
		$height = 98;
		$baseline = 32;
		$tracking = 3;
		$leading = 16;
		$left = 25;
		$font_size = 7.5;
	
		// Create Image and Allocate Colours
		$image = ImageCreate( $width, $height );
		if(!$image) { return false; }
		
		$background_rgb = $this->hex_to_rgb($this->colors['background']);
		$font_rgb 		= $this->hex_to_rgb($this->colors['font']);
		
		$background_color = ImageColorAllocate( $image, (int)$background_rgb['red'], (int)$background_rgb['green'], (int)$background_rgb['blue'] );
		$font_color 	  = ImageColorAllocate( $image, (int)$font_rgb['red'], (int)$font_rgb['green'], (int)$font_rgb['blue'] );
		
		// create the background color 
		imagefilledrectangle($image, 0, 0, $width, $height, $background_color);
		// write out each charater 	
		$array = str_split( strtoupper( $this->umbrella_name ) );
		$hpos = $left;
	
		for($i=0; $i<count($array); $i++)
		{
			if( ord($array[$i]) != 10 ) {
				$bbox = imagettftext( $image, $font_size, 0, $hpos, $baseline, $font_color, $this->font_file, $array[$i]);
				$hpos = $bbox[2]+$tracking;
			} else {
				$hpos = $left;
				$baseline += $leading;
			}
		}
				
		
		$final_image = $this->images_directory.'ubcHeader.gif';
		fopen($final_image, 'w');
		
		$success = ImageGIF( $image, $final_image );
		
		ImageDestroy($image);
		
		return $success;
	}
	
	/**
	 * generate_unit_image function.
	 * 
	 * @access public
	 * @return void
	 */
	private function generate_unit_image() {
		
		// Basic Image Parameters
		$width = 314;
		$height = 98;
		$baseline = 32;
		$tracking = 4;
		$leading = 19;
		$left = 28;
		$font_size = 10;
		
		if( $this->unit_type == 'academic' ) {
			$tracking = 2;	
		} else {
			$this->unit_name = strtoupper($this->unit_name);
		}
		
		// Create Image and Allocate Colours
		$image = ImageCreate($width,$height);
		if(!$image) { return false; }
		
		$background_rgb = $this->hex_to_rgb($this->colors['background']);
		$font_rgb 		= $this->hex_to_rgb($this->colors['font']);
		
		$background_color = ImageColorAllocate( $image, (int)$background_rgb['red'], (int)$background_rgb['green'], (int)$background_rgb['blue'] );
		$font_color 	  = ImageColorAllocate( $image, (int)$font_rgb['red'], (int)$font_rgb['green'], (int)$font_rgb['blue'] );

		//draw unit text
		$array = str_split($this->unit_name);
		$hpos = $left;
		
		imagefilledrectangle($image, 0, 0, $width, $height, $background_color);
		for($i=0; $i<count($array); $i++)
		{
			if( ord($array[$i]) != 10 ) {
				$bbox = imagettftext( $image, $font_size, 0, $hpos, $baseline, $font_color, $this->font_file, $array[$i]);
				$hpos = $bbox[2]+$tracking;
			} else {
				$hpos = $left;
				$baseline += $leading;
			}
		}
		
		
		$final_image = $this->images_directory.'ubcSubUnit.gif';
		fopen($final_image, 'w');
		
		$success = ImageGIF( $image, $final_image );
		
		ImageDestroy($image);
		return $success;
	}
	
	private function generate_place_of_mind() {
		
		$colorbg = imagecreate('188','196');
		$pom_rgb = $this->hex_to_rgb($this->pom_color);
		$background_color = @ImageColorAllocate($colorbg,$pom_rgb['red'],
			$pom_rgb['green'],$pom_rgb['blue']);
			
		// Creates the colored canvas
		imagejpeg($colorbg, $this->images_directory.'/colored1.jpg');
		ImageDestroy($colorbg);
		
		// Double Sprite
		$imgsrc = imagecreatefromjpeg($this->images_directory.'/colored1.jpg');
		$stamp = imagecreatefrompng($this->image_library_path.'sprite_watermark.png');
		
		imagecopy($imgsrc, $stamp, 0, 0, 0, 0, 188, 196);
		
		$placeofmind_pngcached = $this->images_directory.'pom_image.png';
		imagepng($imgsrc,$placeofmind_pngcached);
		$gifsrc = imagecreatefrompng($placeofmind_pngcached);
		imagepalettecopy( $gifsrc, $imgsrc);
		
		$placeofmind_gifcached = $this->images_directory.'placeOfMind.gif';
		$success1 = imagegif($gifsrc,$placeofmind_gifcached);
		
		ImageDestroy($imgsrc);
		ImageDestroy($stamp);
		
		
		// Animated Version
		$colorbg = imagecreate('187','98');
		$background_color = @ImageColorAllocate($colorbg,$pom_rgb['red'],
			$pom_rgb['green'],$pom_rgb['blue']);
		imagejpeg($colorbg, $this->images_directory.'animatecolor1.jpg');
		ImageDestroy($colorbg);
		
		$frames = array();
		for($f=0; $f<11; $f++) {
			$frame_img = imagecreatefromjpeg($this->images_directory.'animatecolor1.jpg');
			$overlay = $f+1;
			$frame_overlay = imagecreatefrompng($this->image_library_path.'/wm_frame'.$overlay.'.png');
			imagecopy($frame_img, $frame_overlay, 0, 0, 0, 0, 187, 98);
			$animated_gifcached = $this->images_directory.'animated_pom'.$f.'.gif';
			imagegif($frame_img,$animated_gifcached);
			$frames[$f] = $animated_gifcached;
			ImageDestroy($frame_img);
			ImageDestroy($frame_overlay);
		}
		
		$framed = array();
		array_fill(0, 9, 20);
		$framed[10] = 210;
		
		$gif = new ClfBaseGIFEncoder($frames,$framed,
			0,
			2,
			0, 0, 0,
			"url"
		);
		
		$animated_org = $this->images_directory.'/PlaceOfMind-Gif-V04-on.gif';
		$success2 = FWrite ( FOpen ($animated_org, "wb" ), $gif->GetAnimation ( ) );
		$file = $this->images_directory.'PlaceOfMind-Gif-V04-off.gif';
		$success3 = copy($animated_org, $file);
				
		// Unanimated Version
		$unanimated_img = imagecreatefromjpeg($this->images_directory.'animatecolor1.jpg');
		$unanimated_overlay = imagecreatefrompng($this->image_library_path.'/nonanimated_watermark.png');
		
		imagecopy($unanimated_img, $unanimated_overlay, 0, 0, 0, 0, 187, 98);
		
		$unanmiated_cache = $this->images_directory.'PlaceOfMind-Gif-V04-unanimated.gif';
		$success4 = imagegif($unanimated_img,$unanmiated_cache);
		
		ImageDestroy($unanimated_img);
		ImageDestroy($unanimated_overlay);
	
		if($success1 && $success2 && $success3 && $success3) {
			return true;
		} else {
			return false;
		}
	}
	
	public function display_ubclogo_image() {
		
		if($this->location == 'okanagan'):
			return $this->stylesheet_directory.'/library/clf-header/imgs/ubcLogo_o'.$this->color_id.'.gif';
		else:
		
		return $this->stylesheet_directory.'/library/clf-header/imgs/ubcLogo'.$this->color_id.'.gif';
		endif;
	}
	
	public function display_unit_image()
	{
		return $this->images_url.'ubcSubUnit.gif';
	}
	
	public function display_header_image()
	{	
		if($this->unit_type == 'faculty') {
			// If the umbrella unit is UBC, use the pre-generated images.
			return $this->stylesheet_directory.'/library/clf-header/imgs/ubcHeader'.$this->color_id.'.gif';
		} else {
			return $this->images_url.'ubcHeader.gif';
		}
	}
	
	public function display_pom_image()
	{
		if($this->color_id == '5' || $this->color_id == '6') {
			return $this->images_url.'placeOfMind.gif';
		}
		return $this->stylesheet_directory.'/library/clf-header/imgs/placeOfMind'.$this->color_id.'.gif';
	}
	
	public function display_pom_unanimated_image()
	{
		if($this->color_id == '5' || $this->color_id == '6') {
			return $this->images_url.'PlaceOfMind-Gif-V04-unanimated.gif';
		}
		return $this->stylesheet_directory.'/library/clf-header/imgs/PlaceOfMind-Gif-V04-unanimated'.$this->color_id.'.gif';
	}
	
	public function display_pom_on_image()
	{
		if($this->color_id == '5' || $this->color_id == '6') {
			return $this->images_url.'PlaceOfMind-Gif-V04-on.gif';
		}
		return $this->stylesheet_directory.'/library/clf-header/imgs/PlaceOfMind-Gif-V04-on'.$this->color_id.'.gif';
	}
	
	public function display_pom_off_image()
	{
		if($this->color_id == '5' || $this->color_id == '6') {
			return $this->images_url.'PlaceOfMind-Gif-V04-off.gif';
		}
		return $this->stylesheet_directory.'/library/clf-header/imgs/PlaceOfMind-Gif-V04-off'.$this->color_id.'.gif';
	}
	
}
endif;