<?php 
/** 
 * CLF 
 * Admin Settings Panel
 *
 */
add_action('admin_init', 'clf_base_clf');

add_filter("clf_base_add_style_path",'clf_base_add_clf_styles');
/**
 * clf_base_clf function.
 * 
 * @access public
 * @return void
 */
function clf_base_clf() {
	add_settings_section('clf', 'UBC CLF', 'clf_base_theme_options_clf', 'clf-base-theme-options');
	
	add_settings_field('clf-base-clf-location', 'Location', 'clf_base_theme_options_clf_location', 'clf-base-theme-options', 'clf');
	add_settings_field('clf-base-clf-mega_menu', 'Mega Menu', 'clf_base_theme_options_clf_mega_menu', 'clf-base-theme-options', 'clf');
	
	add_settings_field('clf-base-clf-pom', 'Place of Mind Dropdown', 'clf_base_theme_options_clf_place_of_mind', 'clf-base-theme-options', 'clf');
	add_settings_field('clf-base-clf-search', 'Site Specific Search', 'clf_base_theme_options_clf_search', 'clf-base-theme-options', 'clf');
	add_settings_field('clf-base-clf-unit-contact', 'Unit Contact Info', 'clf_base_theme_options_clf_unit_contact', 'clf-base-theme-options', 'clf');
	add_settings_field('clf-base-clf-faculty-contact', 'Faculty or Umbrella Unit Info', 'clf_base_theme_options_clf_faculty_contact', 'clf-base-theme-options', 'clf');
	
}

/**
 * clf_base_add_clf_styles function.
 * 
 * @access public
 * @param mixed $paths
 * @return void
 */
function clf_base_add_clf_styles($paths)
{
	global $clf_base_options;
	$location = ( isset($clf_base_options['clf_header']['location']) ? $clf_base_options['clf_header']['location'] : "vancouver" );
	switch($location){
		case 'okanagan': 
			$paths[] = '/library/clf/css/clf-okanagan.css';
		break;
		default:
			$paths[] = '/library/clf/css/clf.css';
		break;
	}
		
	
	return $paths;
}




/**
 * clf_base_theme_options_clf function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_clf() { }

/**
 * clf_base_theme_options_clf_mega_menu function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_clf_mega_menu() {
	global $clf_base_options;
	?>
	<div class="explanation">
	<h3><label class="clear"><input type="checkbox" name="clf_base[clf][mega_menu]" value="1" <?php checked(isset($clf_base_options['clf']['mega_menu'])); ?> /> Enable CLF Mega Menu</label></h3>
	<p>The Mega Menu is the menu that slides down when the user clicks the 'Campuses', 'UBC Directories' or 'UBC QuickLinks' buttons at the top of the page. When this option is disabled, those buttons will instead link to the relevant pages on UBC.ca.</p>
	</div>
	
		
	<div class="half">
		<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/mega2.png" />
	</div>
	<div class="half">
		<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/mega1.png" />
	</div>
	
	
	<?php 
}

/**
 * clf_base_theme_options_clf_place_of_mind function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_clf_place_of_mind() {
	global $clf_base_options;
?>	
	<div class="explanation">
	<h3><label><input type="checkbox" name="clf_base[clf][pom]" value="1" <?php checked(isset($clf_base_options['clf']['pom'])); ?> /> Enable Place of Mind Menu</label></h3>
	<p >The 'a place of mind' dropdown is triggered when the 'a place of mind' button (next to the UBC crest) is clicked. It loads the latest relevant entries on aplaceofmind.ubc.ca. When this option is disabled the button links directly to aplaceofmind.ubc.ca.</p>
	<div >
		<label>Source Feed Url:</label><br />
		<input type="text" name="clf_base[clf][pom_feed]" value="<?php echo esc_attr($clf_base_options['clf']['pom_feed']); ?>" size="79" /><br /><br />
		
		
	</div>
	<div class="half">
		<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/pom2.png" />
	</div>
	<div class="half">
		<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/pom1.png" />
		
	</div>
	<?php 
}

/**
 * clf_base_theme_options_clf_search function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_clf_search() {
	global $clf_base_options;
	?>
	<div class="explanation">
	<p>The search bar on the CLF header performs a Google and shows the search results on a central UBC search result page at <a href="http://www.ubc.ca/search/" target="_blank">http://www.ubc.ca/search/</a>.   
	</p>
	<p>You may enable the search to cover all of ubc.ca or only your specific sites.</p>
	<p>Example 1: Specifying <strong>ubc.ca</strong> and the search will cover all sites within ubc.ca, including <em>www.science.ubc.ca</em> and <em>www.arts.ubc.ca</em>.</p><p>Example 2: Specifying <strong>publicaffairs.ubc.ca</strong> will limit the search to sites in the Public Affairs site.</p>
	<p>You may enable the search to cover all of ubc.ca or only your specific sites.</p>
	</div>
	<label>Domain to Search:</label><br />
	<input type="text" class="text" name="clf_base[clf][search_domain]" value="<?php echo esc_attr($clf_base_options['clf']['search_domain']); ?>" /><br /><br />
	<div >
	
	</div>
	<div class="half">
		<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/search1.png" />
	</div>
	<div class="half">
		<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/search2.png" />
		
	</div>
	
	<?php 
}

/**
 * clf_base_theme_options_clf_unit_contact function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_clf_unit_contact() {
	global $clf_base_options;
	
	foreach( $clf_base_options['clf'] as $key => $option ):
		if( substr($key, 0, 5) == 'unit_' ):
			 $variable = substr($key, 5);
			// extract the varible 
			$$variable = ( isset($option) ? $option: "");
		endif;
	endforeach;
	
	$textarea = ( isset($textarea) ? $textarea: ""); 
	
	?>
	<div style="overflow: auto">
		<div class="half">
			<p>The CLF footer provides a standardized unit contact information area. The information in the following form will populate the footer contact area. All fields except the unit's name are optional in this area.</p>
		</div>
		<div class="half">
			<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/unit-contact1.png" />
		</div>
	</div>
	<label>Unit Name: <span class="required">required</span></label><br />
	<input type="text" class="text"  name="clf_base[clf][unit_name]" value="<?php echo esc_attr($name); ?>"  /> <br />
	

	<strong>Address:</strong><br />
	<label>Street Address:</label><br />
	<input type="text"  class="text"  name="clf_base[clf][unit_address1]" value="<?php echo esc_attr($address1); ?>"  /> <br />
	<input type="text" class="text"  name="clf_base[clf][unit_address2]" value="<?php echo esc_attr($address2); ?>" /> <br />
	
	<div class="half">
		<label>City:</label><br />
		<input type="text" class="text"  name="clf_base[clf][unit_city]" value="<?php echo esc_attr($city); ?>" /> 
	</div>
	<div class="half">
		<label>Province / State / Region:</label><br />
		<input type="text" class="text"   name="clf_base[clf][unit_province]" value="<?php echo esc_attr($province); ?>" /> 
	</div>
	<div class="half">
		<label>Postal / Zip Code:</label><br />
		<input type="text" class="text" name="clf_base[clf][unit_postal]" value="<?php echo esc_attr($postal); ?>"/> 
	</div>
	<div class="half">
		<label>Country:</label><br />
		<input type="text" class="text" name="clf_base[clf][unit_country]" value="<?php echo esc_attr($country); ?>" /> 
	</div>
	<div class="half">
		<label>Email:</label><br />
		<input type="text" class="text" name="clf_base[clf][unit_email]" value="<?php echo esc_attr($email); ?>" /> 
	</div>
	
	<div class="half">
		<label>Website Url:</label><br />
		<input type="text" class="text" name="clf_base[clf][unit_website]" value="<?php echo esc_attr($website); ?>" /> 
	</div>
	<div class="half">
		<label>Phone:</label><br />
		<input type="text" class="text" name="clf_base[clf][unit_phone]" value="<?php echo esc_attr($phone); ?>" /> 
	</div>
	<div class="half">
		<label>Fax:</label><br />
		<input type="text" class="text" name="clf_base[clf][unit_fax]" value="<?php echo esc_attr($fax); ?>" /> 
	</div>
	<div class="clear">
		<label>Other info:</label><br />
		<textarea type="text" class="text" name="clf_base[clf][unit_textarea]" style="width:554px; height:100px;"><?php echo esc_textarea($textarea); ?></textarea><br /> <span>HTML allowed</span>
	</div>
	<?php 
}

/**
 * clf_base_theme_options_clf_faculty_contact function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_clf_faculty_contact() {
	global $clf_base_options;
	
	foreach( $clf_base_options['clf'] as $key => $option ):
		if( substr($key, 0, 8) == 'faculty_' ):
			 $variable = substr($key, 8);
			// extract the varible 
			$$variable = ( isset($option) ? $option: "");
		endif;
	endforeach;
	
	$textarea = ( isset($textarea) ? $textarea: ""); 
	?>
	<div style="overflow: auto">
		<div class="half">
				<p>For units that are part of a larger body, the CLF footer provides a contact information area for the overarching body as well. All fields are optional. </p>
		</div>
		<div class="half">
			<img src="<?php echo get_bloginfo('stylesheet_directory');?>/library/clf/panel-img/faculty-contact1.png" />
		</div>
	</div>
	
	<label>Faculty or Umbrella Unit Name: </label><br />
		<input type="text" class="text"  name="clf_base[clf][faculty_name]" value="<?php echo esc_attr($name); ?>"  /> <br />
	
	<strong>Address:</strong><br />
	<label>Street Address:</label><br />
	<input type="text"  class="text"  name="clf_base[clf][faculty_address1]" value="<?php echo esc_attr($address1); ?>"  /> <br />
	<input type="text" class="text"  name="clf_base[clf][faculty_address2]" value="<?php echo esc_attr($address2); ?>" /> <br />
	
	<div class="half">
		<label>City:</label><br />
		<input type="text" class="text"  name="clf_base[clf][faculty_city]" value="<?php echo esc_attr($city); ?>" /> 
	</div>
	<div class="half">
		<label>Province / State / Region:</label><br />
		<input type="text" class="text"   name="clf_base[clf][faculty_province]" value="<?php echo esc_attr($province); ?>" /> 
	</div>
	<div class="half">
		<label>Postal / Zip Code:</label><br />
		<input type="text" class="text" name="clf_base[clf][faculty_postal]" value="<?php echo esc_attr($postal); ?>"/> 
	</div>
	<div class="half">
		<label>Country:</label><br />
		<input type="text" class="text" name="clf_base[clf][faculty_country]" value="<?php echo esc_attr($country); ?>" /> 
	</div>
	<div class="half">
		<label>Email:</label><br />
		<input type="text" class="text" name="clf_base[clf][faculty_email]" value="<?php echo esc_attr($email); ?>" /> 
	</div>
	
	<div class="half">
		<label>Website Url:</label><br />
		<input type="text" class="text" name="clf_base[clf][faculty_website]" value="<?php echo esc_attr($website); ?>" /> 
	</div>
	<div class="half">
		<label>Phone:</label><br />
		<input type="text" class="text" name="clf_base[clf][faculty_phone]" value="<?php echo esc_attr($phone); ?>" /> 
	</div>
	<div class="half">
		<label>Fax:</label><br />
		<input type="text" class="text" name="clf_base[clf][faculty_fax]" value="<?php echo esc_attr($fax); ?>" /> 
	</div>
	<div class="clear">
		<label>Other info:</label><br />
		<textarea type="text" class="text" name="clf_base[clf][faculty_textarea]" style="width:554px; height:100px;"><?php echo esc_textarea($textarea); ?></textarea> <br /><span>HTML allowed</span>
	</div>
	<?php 
}

