<?php

if( isset($clf_base_options['custom_fields']['page_permissions']) ):
	/* Use the admin_menu action to define the custom boxes */
	add_action('admin_menu', 'clf_base_permissions_box');
	
	/* Use the save_post action to do something with the data entered */
	add_action('save_post', 'clf_base_permissions_box_save');
endif;

/* Adds a custom section to the "advanced" Post and Page edit screens */
function clf_base_permissions_box() {
	add_meta_box( 'clf_base_permisions_box', __( 'Page View Permissions', 'clf_base' ), 'clf_base_permissions_box_inner', 'page', 'side','low' );
}

add_filter('the_content','clf_base_permissions_content');
/* Prints the inner fields for the custom post/page section */
function clf_base_permissions_box_inner() {
 
  global $post;
  
  $clf_base_permission_a = get_post_meta($post->ID, '_permissions');
  $clf_base_permission =  $clf_base_permission_a[0];
  $permissions_text_a = get_post_meta($post->ID, '_permissions_text');
   $permissions_text = $permissions_text_a[0];
  if($clf_base_permission == "")
 	 $clf_base_permission = "everyone";
 
 
  // Use nonce for verification
  echo '<input type="hidden" name="clf_base_permissions_noncename" id="clf_base_permissions_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
  // The actual fields for data entry
  ?><div id="clf_base_permissions_box">
  	<label for="clf_base_permissions">Choose who can view this page</label>

  	<select name="clf_base_permissions" id="clf_base_permissions">
  		<option value='everyone' <?php selected('everyone', $clf_base_permission); ?>>Everyone</option>
  		<option value='loggedin' <?php selected('loggedin', $clf_base_permission); ?>>Loggin Users* </option>
  		<option value='subscriber' <?php selected('subscriber', $clf_base_permission); ?>>Subscriber - Site Members</option>
  		<option value='contributor' <?php selected('contributor', $clf_base_permission); ?>>Contributors </option>
  		<option value='author' <?php selected('author', $clf_base_permission); ?>>Authors</option>
   	</select>
  	<br /><p>Note that the the selected role is the minimal role required to view the content of the page.<br />
  		*anyone that has a valid CWL can see it.</p>
  	
  	
  	<br />
  	<labe for="clf_base_permissions_text">Non-Private Content</label>
  	<textarea name="clf_base_permissions_text" id="clf_base_permissions_text" style="width:100%; height:200pxresize:vertical;"><?php echo $permissions_text; ?></textarea>
  	<p>Will only be shown to people who can't see the private content.</p>
  	</div>
  <?php
}





function clf_base_permissions_content($content)
{	
	if(is_admin())
		return $content;
	
	global $post,$current_user;
	//$user = new WP_User( $id );
	
	$clf_base_permission_a = get_post_meta($post->ID, '_permissions');
	$permissions_text = get_post_meta($post->ID, '_permissions_text');
	
	
    $clf_base_permission =  $clf_base_permission_a[0];
   
   	if( $clf_base_permission == "everyone" || !$clf_base_permission)
   		return $content;
   	   	
	if ( is_user_logged_in() && $clf_base_permission == ('administrator'||'editor'||'contributor'||'author'||'subscriber'||'loggedin') ) {

		if( $clf_base_permission == 'loggedin')
			return $content;
		
		switch($clf_base_permission) {
			case ('administrator'):
				if(current_user_can( 'administrator' ))
					return $content;
			break;
			case ('editor'):
				if( current_user_can('editor') || current_user_can( 'administrator' )) 
					return $content;
			break;
			case ('author'):
				
				if(current_user_can('author') || current_user_can('editor') || current_user_can( 'administrator' ))	
					return $content;
			break;
			case ('contributor'):
				
				if(current_user_can('contributor') || current_user_can('author') || current_user_can('editor') || current_user_can( 'administrator' ))
					return $content;
			break;		
			case ('subscriber'):
				
				if(current_user_can('subscriber') || current_user_can('contributor') || current_user_can('author') || current_user_can('editor') || current_user_can( 'administrator' ))
					return $content;
			break;
			
		}
	
		return do_shortcode($permissions_text[0]);
	
	}
	return do_shortcode($permissions_text[0]);



}


/**
 * clf_base_permissions_box_save function.
 * 
 * @access public
 * @param mixed $post_id
 * @return void
 */
function clf_base_permissions_box_save( $post_id ) {

	// verify this came from the our screen and with proper authorization,
	// because save_post can be triggered at other times
	
	if ( !wp_verify_nonce( $_POST['clf_base_permissions_noncename'], plugin_basename(__FILE__) )) {
	return $post_id;
	}
	
	// verify if this is an auto save routine. If it is our form has not been submitted, so we dont want
	// to do anything
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
	return $post_id;
	
	
	// Check permissions
	if ( 'page' == $_POST['post_type'] ) {
	if ( !current_user_can( 'edit_page', $post_id ) )
	return $post_id;
	} 
	// OK, we're authenticated: we need to find and save the data
	
	$data = $_POST['clf_base_permissions'];
	$permisssions_text = $_POST['clf_base_permissions_text'];
	
	// Do something with $mydata 
	// probably using add_post_meta(), update_post_meta(), or 
	// a custom table (see Further Reading section below)
	
	if(get_post_meta($post_id, '_permissions') == "")  
		add_post_meta($post_id, '_permissions', $data, true);  
	
	elseif($data != get_post_meta($post_id, '_permissions', true))  
		update_post_meta($post_id, '_permissions', $data);  
		
	if(get_post_meta($post_id, '_permissions') == "")  
		add_post_meta($post_id, '_permissions', $permisssions_text, true);  
	
	elseif($data != get_post_meta($post_id, '_permissions_text', true))  
		update_post_meta($post_id, '_permissions_text', $permisssions_text);  
	
	
	
   return $mydata;
}





