<?php
/** 
 * Display Options
 * 
 * 
 * 
 */

global $clf_base_load_backend;
if($clf_base_load_backend)
	require_once("panel.php");


add_action('init', 'clf_base_display_options_init'); /* adds the layout styles to the theme */

/**
 * clf_base_display_options_init function.
 * 
 * @access public
 * @return void
 */
function clf_base_display_options_init() {
	global $clf_base_options;
	
	remove_action( "hybrid_after_singular", 'custom_field_series' ); // this was causing an error in dev
	// order of the byline 
	if( $clf_base_options['post']['byline']['order'] == "before" )
	{
		remove_action('hybrid_before_entry', 'hybrid_byline');
		add_action( 'hybrid_before_entry', 'hybrid_byline', 0 );
		
	}
	// copyright 
	if(isset($clf_base_options['display_options']['license']) && $clf_base_options['display_options']['license'] != "copyright" )
		add_filter('hybrid_meta_copyright', 'clf_base_display_options_license');
		
	add_filter('hybrid_byline', 'clf_base_display_options_byline');
	add_filter('hybrid_entry_meta','clf_base_display_options_meta_data');
	add_filter('comments_template','clf_base_disable_comments');
	add_filter('wp_title','clf_base_filter_head_title',10,2);
	
	add_action("hybrid_head",'clf_base_IE_compatibility');
	add_action("hybrid_head",'clf_base_display_favicon');
	// site title switch 
	if( isset($clf_base_options['display_options']['header']['site-title']) ):
		add_action( 'hybrid_after_header','clf_base_display_options_sitename',12);
		// add_action( 'hybrid_before_container', 'clf_base_display_options_sitename', 1);
	endif;
	// site tagline switch
	if( isset($clf_base_options['display_options']['header']['tagline']) ):
		add_action( 'hybrid_after_header','clf_base_display_options_tagline',12);
		// add_action( 'hybrid_before_container', 'clf_base_display_options_tagline',1 );
	endif;
		
	if(is_numeric($clf_base_options['display_options']['feed-cache-time']) && isset($clf_base_options['display_options']['feed-cache-time']))
		add_filter( 'wp_feed_cache_transient_lifetime', "clf_base_feed_cache_filter", 12);
	
	if(isset($clf_base_options['display_options']['header']['widget-area'])):
		// register the frontpage widget
		register_sidebar( 
			array( 'name' => __('Header', 'hybrid'), 
			'id' => 'header-widget', 
			'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 
			'after_widget' => '</div></div>', 
			'before_title' => '<h3 class="widget-title">', 
			'after_title' => '</h3>' ) );
	
	
		add_action( 'hybrid_after_header', 'clf_base_header_widget',11);
		
		
		// fix for droping in the navigation widget 'dynamic_sidebar', $wp_registered_widgets[$id]
	endif;
	// only so stuff if the plugin is enabled 
	if(function_exists('sharing_display')):
			
		// removing the default filters that the plugin comes with
		remove_filter( 'the_content', 'sharing_display',19);
		remove_filter( 'the_excerpt', 'sharing_display', 19);
		// placing the funtion back into play - this will make it show up on all the pages and posts
		add_filter('hybrid_entry_meta', 'sharing_display', 19);
	endif; 

	
}
/**
 * clf_base_filter_head_title function.
 * 
 * @access public
 * @param mixed $title
 * @param mixed $seperator
 * @return void
 */
function clf_base_filter_head_title($title,$seperator)
{
	if(is_front_page() && is_home() ):
		if(get_bloginfo( 'description' ) == ''):
			$seperator_size = strlen($seperator);
			$seperator_size++;
			$title = substr($title, 0, -$seperator_size);
			
		endif;

	endif;
	return $title;

}
/**
 * clf_base_IE_compatibility function.
 * 
 * @access public
 * @return void
 */
function clf_base_display_favicon()
{	
	global $clf_base_options;
	if( isset($clf_base_options['display_options']['favicon']) && !empty($clf_base_options['display_options']['favicon'])):
		echo "<link rel=\"shortcut icon\" href=\"".esc_url($clf_base_options['display_options']['favicon'])."\" />\n";
	else:
		echo "<link rel=\"shortcut icon\" href=\"http://ubc.ca/_ubc_clf/img/favicon.ico\" />\n";
	endif;
}


/**
 * clf_base_IE_compatibility function.
 * 
 * @access public
 * @return void
 */
function clf_base_IE_compatibility()
{
	echo "<meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge,chrome=1\" />\n";
}
/**
 * clf_base_feed_cache_filter function.
 * 
 * @access public
 * @param mixed $time
 * @return void
 */
function clf_base_feed_cache_filter($time)
{
	global $clf_base_options;
		$cache_in_sec = $clf_base_options['display_options']['feed-cache-time']*60;
	
	if($cache_in_sec > 300)
		return 300;
	else
		return $cache_in_sec;
		
}

/**
 * clf_base_disable_comments function.
 * 
 * @access public
 * @param mixed $template
 * @return void
 */
function clf_base_disable_comments($template) { 
	global $clf_base_options;
		
		if($clf_base_options['display_options']['discussion']['page-diabled'] &&  is_page())
		return str_replace("comments.php", "no-comments.php", $template);
	
	return $template;
}

/**
 * clf_base_display_options_byline function.
 * 
 * @access public
 * @param mixed $current_byline
 * @return void
 */
function clf_base_display_options_byline( $current_byline ) {
	global $clf_base_options,$post;
	
	
	if( (is_archive() || is_single() || is_home()|| $post->post_type =='post') && $clf_base_options['post']['byline']['enable']):
	
		if(empty($clf_base_options['post']['byline']['custom']))
			return $current_byline;
	
		if ( current_user_can( 'edit_posts' ) )
			$byline .= ' <span class="byline-sep byline-sep-edit separator">|</span> <span class="edit"><a href="' . get_edit_post_link( $post->ID ) . '" title="' . __('Edit post', 'hybrid') . '">' . __('Edit', 'hybrid') . '</a></span>';
		
		$byline .= '</p>';
		
		return '<p class="byline">'.do_shortcode($clf_base_options['post']['byline']['custom']).$byline;
	else:
		return "";
	endif;
}


/**
 * clf_base_display_options_meta_data function.
 * 
 * @access public
 * @param mixed $current_meta_data
 * @return void
 */
function clf_base_display_options_meta_data($current_meta_data)
{
	global $clf_base_options,$post;
	if( (is_archive() || is_single() || is_home() || $post->post_type =='post')  && $clf_base_options['post']['meta-data']['enable']):
		
		if(empty($clf_base_options['post']['meta-data']['custom']))
			return $current_meta_data;
		$meta_data  = '<p class="entry-meta post-meta-data">';
		$meta_data .= do_shortcode($clf_base_options['post']['meta-data']['custom']);
		$meta_data  .= '</p>';
	
		return $meta_data;
		
	elseif( (is_page() || $post->post_type =='page') && $clf_base_options['page']['meta-data']['enable']):
		
		if(empty($clf_base_options['page']['meta-data']['custom']))
			return $current_meta_data;
			
		$meta_data  = '<p class="entry-meta post-meta-data">';
		$meta_data .= do_shortcode($clf_base_options['page']['meta-data']['custom']);
		
		if ( current_user_can( 'edit_pages' ) )
			$meta_data .= ' <span class="byline-sep byline-sep-edit separator">|</span> <span class="edit"><a href="' . get_edit_post_link( $post->ID ) . '" title="' . __('Edit post', 'hybrid') . '">' . __('Edit', 'hybrid') . '</a></span>';
		
		$meta_data  .= '</p>';
		return $meta_data;
	else:
		return "";
	endif;
	
}

/**
 * clf_base_display_options_sitename function.
 * 
 * @access public
 * @return void
 */
function clf_base_display_options_sitename() {
	$tag = ( is_home() || is_front_page() ) ? 'h1' : 'div';

	$title = get_bloginfo( 'name' );

	if ( $title )
		$title = '<' . $tag . ' id="site-title"><a href="' . get_bloginfo( 'url' ) . '" title="' . $title . '"><span>' . $title . '</span></a></' . $tag . '>';

	echo apply_filters( 'hybrid_site_title', $title );
}


/**
 * clf_base_display_options_tagline function.
 * 
 * @access public
 * @return void
 */
function clf_base_display_options_tagline() {
	$tag = ( is_home() || is_front_page() ) ? 'h2' : 'div';

	$desc = get_bloginfo( 'description' );

	if ( $desc )
		$desc = "\n\t\t\t" . '<' . $tag . ' id="site-description"><span>' . $desc . '</span></' . $tag . '>' . "\n";
	
	echo apply_filters( 'hybrid_site_description', $desc );
}


add_filter('hybrid_home_entry_title','clf_base_title');
add_filter('hybrid_entry_title','clf_base_title');
/**
 * clf_base_title function.
 * 
 * @access public
 * @return void
 */
function clf_base_title() {
	global $post, $clf_base_options;

	if ( is_front_page() && !is_home() && $clf_base_options['display_options']['header']['site-title'] ):
		$title = the_title( '<h2 class="' . $post->post_type . '-title entry-title"><a href="' . get_permalink() . '" title="' . the_title_attribute( 'echo=0' ) . '" rel="bookmark">', '</a></h2>', false );

	elseif ( is_singular() && !$clf_base_options['display_options']['header']['site-title'] && !(get_post_type() == 'post')):
		$title = the_title( '<h1 class="' . $post->post_type . '-title entry-title"><a href="' . get_permalink() . '" title="' . the_title_attribute( 'echo=0' ) . '" rel="bookmark">', '</a></h1>', false );

	elseif ( 'link_category' == get_query_var( 'taxonomy' ) ):
		$title = false;

	else:
		$title = the_title( '<h2 class="entry-title"><a href="' . get_permalink() . '" title="' . the_title_attribute( 'echo=0' ) . '" rel="bookmark">', '</a></h2>', false );
	endif;
	return $title;
}

/**
 * clf_base_display_options_license function.
 * 
 * @access public
 * @param mixed $meta
 * @return void
 */
function clf_base_display_options_license($meta){
	global $clf_base_options;
		$meta = '<meta name="copyright" content="http://creativecommons.org/licenses/' . $clf_base_options['display_options']['license'] . '/3.0/" />'. "\n";
	return $meta;
}

/**
 * clf_base_header_widget function.
 * 
 * @access public
 * @return void
 */
function clf_base_header_widget()
{	
	
	if ( is_sidebar_active( 'header-widget' ) ) : ?>

			<div class="header-widget utility">

				<?php dynamic_sidebar( 'header-widget' ); ?>

			</div><!-- #header-widget .utility -->

	<?php endif; 
}

