<?php 
/** 
 * Display Options
 * Admin Settings Panel
 *
 */
add_action('admin_init', 'clf_base_display_options');


/**
 * clf_base_display_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_display_options() {
	add_settings_section('display-options', 'Display Options', 'clf_base_theme_options_display_options', 'clf-base-theme-options');
	add_settings_field('clf-base-clf-display-options-post', 'Post Options', 'clf_base_theme_options_display_post_options', 'clf-base-theme-options', 'display-options');
	add_settings_field('clf-base-clf-display-options-page', 'Page Options', 'clf_base_theme_options_display_page_options', 'clf-base-theme-options', 'display-options');
	add_settings_field('clf-base-clf-display-options-discussion', 'Discussion', 'clf_base_theme_options_display_discussion', 'clf-base-theme-options', 'display-options');
	add_settings_field('clf-base-clf-display-options-archive', 'Archive Options', 'clf_base_theme_options_archive_options', 'clf-base-theme-options', 'display-options');
	
	add_settings_field('clf-base-clf-display-options-favicon', 'Favicon', 'clf_base_theme_options_favicon', 'clf-base-theme-options', 'display-options');
	add_settings_field('clf-base-clf-display-options-feed-cache-time', 'Feed Cache', 'clf_base_theme_options_feed_cache_time', 'clf-base-theme-options', 'display-options');
	add_settings_field('clf-base-clf-display-options-license', 'License', 'clf_base_theme_options_license', 'clf-base-theme-options', 'display-options');
	add_settings_field('clf-base-clf-display-options-header', 'Header', 'clf_base_theme_options_header', 'clf-base-theme-options', 'display-options');
	wp_register_style('clf-base-css-ui-display-options', get_bloginfo('stylesheet_directory').'/library/display-options/panel.css');
	
	add_action('clf_base_admin_ui','clf_base_display_options_ui');
	
}	
/**
 * clf_base_display_options_ui function.
 * 
 * @access public
 * @return void
 */
function clf_base_display_options_ui() {
	wp_enqueue_script('clf-base-display-options-panel', get_bloginfo('stylesheet_directory').'/library/display-options/panel.js', array('jquery'));
	wp_enqueue_style('clf-base-css-ui-display-options');
}

/**
 * clf_base_theme_options_display_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_display_options() { }

/**
 * clf_base_theme_options_display_post_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_display_post_options() {
	global $clf_base_options;
		$date_format = get_option('date_format');
		
	?>
	
	<div class="clear">
		<div class="explanation">
		<h3>Post byline</h3>
		<p>Control how the post's byline is displayed.  You can choose whether the byline appears before or after the post title, and how the sentence structure of the byline is arranged.</p>
		<p>Tags such as [post-author-link] and [date] will be substituted with the relevant post meta data, so arrange these to suit your needs.</p>
		</div>
		<label><input type="checkbox" name="clf_base[post][byline][enable]" value="1" <?php checked( isset($clf_base_options['post']['byline']['enable'])); ?> > Display the post byline</label>
	</div>
	<div><label>Display the byline </label>
		<select name="clf_base[post][byline][order]">
			<option value="after" <?php selected('after', $clf_base_options['post']['byline']['order']); ?> >after the post title </option>
			<option value="before" <?php selected('before', $clf_base_options['post']['byline']['order']); ?>>before the post title </option>
			
		</select>
	</div>	
	<hr />
	<div id="post-byline-options" class="options-shell half">
		Choose Template:
		<div class="option">
			<label><input type="radio" alt="By [posts-author-link] on [date]" name="clf_base[post][byline][type]" value="author-link-and-date" 
			<?php checked('author-link-and-date', $clf_base_options['post']['byline']['type']); ?>/> 
			By <a href="#">Author's Nickname</a> on <?php echo date($date_format); ?></label>
		</div>
	
		<div class="option">
			<label><input type="radio" alt="[date]" name="clf_base[post][byline][type]" value="date" 
			<?php checked('date', $clf_base_options['post']['byline']['type']); ?>/> 
			<?php echo date($date_format); ?></label>
		</div>
	</div>
	<div class="half">
		<label>Post byline template</label><br />
		<textarea id="post-byline-options-custom" type="text" class="text" name="clf_base[post][byline][custom]"><?php echo $clf_base_options['post']['byline']['custom']; ?></textarea> 
	</div>
	
	</div>
	
	<div class="padding-top clear">
		<div class="explanation">
		<h3>Post meta data</h3>
		<p>Control how the post's meta data is displayed.  Use one of the predefined meta data templates, or assemble your own using variable tags.</p>
		<p>Available tags include: [permalink], [categories], [tags], [comments] </p>
		</div>
		<label><input type="checkbox" name="clf_base[post][meta-data][enable]" value="1" <?php checked( isset($clf_base_options['post']['meta-data']['enable']) ); ?> > Display the post meta data</label>
	</div>
		
	<div id="post-meta-data-options" class="options-shell half">
		Choose Template:
		<div class="option">
			<label><input type="radio" alt="<a href='[permalink]'>Read More</a> | [comments]" name="clf_base[post][meta-data][type]" value="permalink-comments" 
			<?php checked('permalink-comments', $clf_base_options['post']['meta-data']['type']); ?>/> 
			<a href="#">Read More</a> | <a href="#">3 Comments</a></label>
		</div>
	
		<div class="option">
			<label><input type="radio" alt="Posted in [categories] | Tagged with [tags]" name="clf_base[post][meta-data][type]" value="categories-tags" 
			<?php checked('categories-tags', $clf_base_options['post']['meta-data']['type']); ?>/> 
			Posted in <a href="#">category 1</a> | Tagged with <a href="#">tag 1</a>, <a href="#">tag 1</a>,</label>
		</div>
	</div>
	<div class="half">
		<label>Post meta data template</label><br />
		<textarea  id="post-meta-data-options-custom" type="text" class="text" name="clf_base[post][meta-data][custom]"><?php echo $clf_base_options['post']['meta-data']['custom']; ?></textarea> 
	</div>
	
	</div>
		
	
	<?php 
}
/**
 * clf_base_theme_options_display_page_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_display_page_options() {
	global $clf_base_options;
		$date_format = get_option('date_format');
		
	?>
	<div class="clear">
		<div class="explanation">
		<h3>Page meta data</h3>
		<p>Control how a page's meta data is displayed.  Choose a predefined meta data template, or assemble your own using variable tags.</p>
		<p>Available tags include: [last-updated], [child-pages]</p>
		</div>
		<label><input type="checkbox" name="clf_base[page][meta-data][enable]" value="1" <?php checked( isset($clf_base_options['page']['meta-data']['enable']) ); ?> > Display page meta data</label>
	</div>
		
	<div id="page-meta-data-options" class="options-shell half">
		Choose Template:
		<div class="option">
			<label><input type="radio" alt="Last updated on [last-updated]" name="clf_base[page][meta-data][type]" value="categories-tags" 
			<?php checked('categories-tags', $clf_base_options['page']['meta-data']['type']); ?>/> 
			Last updated on <?php echo date('F j, Y @g:i a'); ?></label>
		</div>
		<div class="option">
			<label><input type="radio" alt="[child-pages]" name="clf_base[page][meta-data][type]" value="permalink-comments" 
			<?php checked('permalink-comments', $clf_base_options['page']['meta-data']['type']); ?>/> 
			Display the child pages
			</label>
		</div>
	</div>
	<div class="half">
		<label>Page meta data template</label><br />
		<textarea  id="page-meta-data-options-custom" type="text" class="text" name="clf_base[page][meta-data][custom]"><?php echo $clf_base_options['page']['meta-data']['custom']; ?></textarea>
		
	</div>
	
	</div>
		
	<?php 
}

/**
 * clf_base_theme_options_display_discussion function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_display_discussion() {
	global $clf_base_options;
	?>
	<div>
		<div class="explanation">
		<h3><label><input type="checkbox"  name="clf_base[display_options][discussion][page-diabled]" value="1" <?php checked( isset($clf_base_options['display_options']['discussion']['page-diabled']) ); ?> /> Disable comments on pages</label></h3>
		<p>Enable/disable commenting across your entire website.  Overrides all other discussion settings.</p>
		</div>
	</div>
	<?php
}

/**
 * clf_base_theme_options_archive_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_archive_options() {
	global $clf_base_options;
	?>
	<div class="explanation">
		<h3><label><input type="checkbox" name="clf_base[images][thumbnail][enable]" value="common" <?php checked(isset($clf_base_options['images']['thumbnail']['enable'])); ?>/> Display post thumbnails on archive pages</label></h3>
		<p>Some posts have thumbnails that are representative of the post.  This option displays the thumbnails (if they exist) in the archive listings.</p>
		
	</div>
	
	<?php
}

/**
 * clf_base_theme_options_header function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_header() {
	global $clf_base_options;
	?>
	<div class="clear">
		<div class="explanation">
		<h3><label><input type="checkbox"  name="clf_base[display_options][header][widget-area]" value="1" <?php checked(  isset($clf_base_options['display_options']['header']['widget-area']) ); ?> />
		Enable Header Widget Area
		</label></h3>
		<p>Enable an additional widget area that allows you to place widgets after the navigation.</p>
		</div>
	</div>
	<div class="explanation">
		<h3><label><input type="checkbox"  name="clf_base[display_options][header][site-title]" value="1" <?php checked( isset($clf_base_options['display_options']['header']['site-title']) ); ?> />
		Display site name
		</label></h3>
		<p>Displays the site name in a header banner under the navigation and above the site content.  The header banner area takes up the whole width of the site.  Useful as a more prominent site identifier.</p>
		</div>
		<p>Site name: <strong><?php echo get_bloginfo('name'); ?></strong>.</p><p>You can change this under <em>Settings &gt; <a href="<?php echo  admin_url('options-general.php'); ?>" target="_blank">General</a></em></p>
	</div>
	<div class="clear">
		<div class="explanation">
		<h3><label><input type="checkbox"  name="clf_base[display_options][header][tagline]" value="1" <?php checked(  isset($clf_base_options['display_options']['header']['tagline']) ); ?> />
		Display site tagline
		</label></h3>
		<p>Displays the site tagline in a header banner under the navigation and above the site content.  Compliments the site name in the header banner area.</p>
		</div>
		<p>Site tagline: <strong><?php echo get_bloginfo('description'); ?></strong>.</p><p>You can change this under <em>Settings &gt; <a href="<?php echo  admin_url('options-general.php'); ?>" target="_blank">General</a></em></p>
	</div>
	

	
	<?php
}

/**
 * clf_base_theme_options_favicon function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_favicon() {
	global $clf_base_options;
	
	if(isset($clf_base_options['display_options']['favicon']) )
		$favicon = $clf_base_options['display_options']['favicon'];
	else
		$favicon  = "http://ubc.ca/_ubc_clf/img/favicon.ico";
	?>
	<div class="explanation">
		<h3>Display favicon</h3>
		<p>A favicon (short for favorites icon), also known as a shortcut icon, website icon, URL icon, or bookmark icon is a file containing one or more small icons, most commonly 16x16 pixels, associated with a particular website.</p>
		<p>To change the default favicon of your website you can add the desired icon to the <a href="<?php echo admin_url('media-new.php'); ?>" target="_blank">media library</a> and then copy the <strong>File URL </strong> into the line below.</p>
		<p>default : http://ubc.ca/_ubc_clf/img/favicon.ico</p>
		</div>
		<label><img class="favicon" src="<?php echo $favicon; ?>" alt="favicon" /> <input type="text"  name="clf_base[display_options][favicon]" value="<?php echo $clf_base_options['display_options']['favicon']; ?>" size="50"  /> (url to the file in .ico format)
		
		</label>
	
	<?php

}


/**
 * clf_base_theme_options_header function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_feed_cache_time() {
        global $clf_base_options; ?>
        <div class="explanation">
                <h3>Duration of feed cache</h3>
                <p>Set the interval in minutes that the Feed will be stored, the minimum is 5 minutes.</p>

        </div>
		<label><input type="text"  name="clf_base[display_options][feed-cache-time]" value="<?php echo $clf_base_options['display_options']['feed-cache-time']; ?>" size="4" /> minutes</label>
        

        <?php

}


function clf_base_theme_options_license() {
	global $clf_base_options;
	
	if( !isset($clf_base_options['display_options']['license']) )
		$clf_base_options['display_options']['license'] = "copyright";
	?>
	<div class="explanation">
		<h3>Select a default website content license</h3>
			<p>*With a Creative Commons license, <strong>you keep your copyright</strong> but allow people to <a href="http://creativecommons.org/learn/licenses/fullrights" target="_blank">copy and distribute your work</a> provided they give you credit &mdash; and only on the conditions you specify here. For those new to Creative Commons licensing, we've prepared a list of <br /><a href="http://creativecommons.org/about/think" target="_blank">things to think about</a>. <br /> *<a href="http://creativecommons.org/choose/" target="_blank">source</a></p>
	</div>
		<label><input type="radio"  name="clf_base[display_options][license]" value="copyright" <?php checked($clf_base_options['display_options']['license'],"copyright"); ?> /> Default - &copy; Copyright The University of British Columbia </label><br />
		<label><input type="radio"  name="clf_base[display_options][license]" value="no-license" <?php checked($clf_base_options['display_options']['license'],"no-license"); ?> /> No License - Nothing is displayed</label><br /><br />
		<strong>Creative Commons - Non Commercial</strong><br />
		<label class="cc by-nc-sa" ><input type="radio"  name="clf_base[display_options][license]" value="by-nc-sa" <?php checked($clf_base_options['display_options']['license'],"by-nc-sa"); ?> /> Attribution-NonCommercial-ShareAlike </label>
		<label class="cc by-nc"><input type="radio"  name="clf_base[display_options][license]" value="by-nc" <?php checked($clf_base_options['display_options']['license'],"by-nc"); ?> /> Attribution-NonCommercial</label>
		<label class="cc by-nc-nd"><input type="radio"  name="clf_base[display_options][license]" value="by-nc-nd" <?php checked($clf_base_options['display_options']['license'],"by-nc-nd"); ?> /> Attribution-NonCommercial-NoDerivs</label><br />
		<strong>Creative Commons - Commercial</strong><br />
		<label class="cc by-sa"><input type="radio"  name="clf_base[display_options][license]" value="by-sa" <?php checked($clf_base_options['display_options']['license'],"by-sa"); ?> /> Attribution-ShareAlike</label>
		<label class="cc by"><input type="radio"  name="clf_base[display_options][license]" value="by" <?php checked($clf_base_options['display_options']['license'],"by"); ?> /> Attribution</label>
		<label class="cc by-nd"><input type="radio"  name="clf_base[display_options][license]" value="by-nd" <?php checked($clf_base_options['display_options']['license'],"by-nd"); ?> /> Attribution-NoDerivs</label>
		<span>Learn more about <a href="http://creativecommons.org/licenses/" target="_blank" >creative commons licenses</a></span>
	<div>
	<label for="license-text">text to be displayed next to the license.</label>
		<textarea cols="70" rows="2"  name="clf_base[display_options][license-text]" id="license-text"><?php 
			if( isset($clf_base_options['display_options']['license-text'])) 
				echo $clf_base_options['display_options']['license-text']; 
				?></textarea>
		
		
	</div>
	<?php


}

