<?php
/** 
 * Images
 * 
 * Lets the user choose what layout grid they want to use and enables that with css
 */


global $clf_base_load_backend;
if($clf_base_load_backend)
	require_once("panel.php");

add_action('init','clf_base_images_init');


/**
 * clf_base_images_init function.
 * 
 * @access public
 * @return void
 */
function clf_base_images_init() {
	global $clf_base_options;
	add_filter( 'get_the_image','clf_base_image_thumbnail_disable',3);
	
	add_theme_support( 'custom-header', array(
			// Header image default
			'default-image'			=> get_bloginfo('stylesheet_directory').'/library/images/header/default.gif',
			// Header text display default
			'header-text'			=> false,
			// Header text color default
			'default-text-color'		=> '000',
			// Header image width (in pixels)
			'width'				=> 980,
			// Header image height (in pixels)
			'height'			=> 150,
			'flex-height' => true
		));
	if($clf_base_options['images']['header']['enable']):
		
		add_action( 'hybrid_after_header','clf_base_image_header_image_display',12);
		// add_action( 'hybrid_before_container','clf_base_image_header_image_display',2);
	endif;
	
	if($clf_base_options['images']['thumbnail']['enable']):
		add_filter('hybrid_body_class', 'clf_base_thumbnail_body_class_filter');
	endif;
}
	  

/**
 * clf_base_thumbnail_body_class_filter function.
 * 
 * @access public
 * @param mixed $body_class
 * @return void
 */
function clf_base_thumbnail_body_class_filter($body_class)
{
	if(is_archive())
		return $body_class. " enable-thumbnails"; 
	else
		return $body_class;
	
}


/**
 * Define the different thumnail sizes.
 * 
 * @access public
 * @return void
 */
add_theme_support( 'post-thumbnails', array( 'post', 'page') );
set_post_thumbnail_size( 125, 100, true );
add_image_size( 'page-header', 980,150, true);
add_image_size( 'single-post-slide',560, 300, true);
add_image_size( 'single-post-slide-high',560, 400, true);
add_image_size( 'single-post-slide-half',280, 200, true);
add_image_size( 'single-post-wide-slide', 980, 200, true);

/**
 * clf_base_image_header_image_display function.
 * 
 * @access public
 * @return void
 */
function clf_base_image_header_image_display()
{
	global $post;
	
	if( get_header_image() || ( wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'page-header') && is_page() ) ):
	?>
	<div id="header-image">
	<?php 
	if(is_page() || is_front_page()):
		// Retrieve the dimensions of the current post thumbnail -- no teensy header images for us!
		$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'page-header');
		
		list($src, $width, $height) = $image;
					
		// Check if it has a thumbnail, and if it's a big one
		if ( has_post_thumbnail( $post->ID ) && $width >= get_custom_header()->width && is_page() ) :		
			// Houston, we have a new header image!
			echo get_the_post_thumbnail( $post->ID, 'page-header' );
		else : ?>
			<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="header image" />
		<?php endif; 
	else:
		?>
		<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="header image" />
		<?php 
	endif;	
	?>
	</div>
	<?php 
	endif;
	
}

/**
 * clf_base_image_thumbnail_disable function.
 * 
 * @access public
 * @param mixed $image
 * @return void
 */
function clf_base_image_thumbnail_disable($image)
{
	global $post, $clf_base_options;
	if( $clf_base_options['images']['thumbnail']['enable'] ):
		
		$final_image = get_the_post_thumbnail();

		
		if( empty( $final_image ) )
			$final_image = $image;
		
		
		return $final_image;
		
	else:
		return null;
	endif;
}


