<?php
/** 
 * Mobile
 * 
 * Lets the user choose what layout grid they want to use and enables that with css
 */


global $clf_base_load_backend;
if($clf_base_load_backend)
	require("panel.php");


require( 'transcode.php' );
require( 'device-detection.php' ); 
require( 'spotlight.php' ); 
	


// register the sidebar to be below everything 
add_action("init","clf_base_init_mobile",20);

// switch to back to the mobile version 
if( isset($_GET['switch-to-mobile']) )
	clf_base_show_mobile_version(); // removed the cookie 


// Display the mobile view
/* 
	* the preview is set
	or
	* settings enabled
	and
	* browser is mobile
*/
if( clf_base_display_mobile_view() ) {
	
	// load the mobile style 	
	add_action("init","clf_base_is_mobile");
	
	// the preview site is being shown
	if( clf_base_display_mobile_preview() ):
		add_filter('post_link','clf_base_mobile_permalink');
		add_filter('page_link','clf_base_mobile_permalink');
		add_filter('tag_link','clf_base_mobile_permalink');
		add_filter('category_link','clf_base_mobile_permalink');
		add_filter('author_link','clf_base_mobile_permalink');
		add_filter('day_link','clf_base_mobile_permalink');
		add_filter('attachment_link','clf_base_mobile_permalink');
		add_filter('month_link','clf_base_mobile_permalink');
		add_filter('paginate_links','clf_base_mobile_permalink');
		add_filter('post_type_link','clf_base_mobile_permalink');
		add_filter('preview_post_link','clf_base_mobile_permalink');
		add_filter('home_url','clf_base_mobile_permalink');
		
		add_filter('search_link','clf_base_mobile_permalink');
		
		add_filter('the_author_posts_link','clf_base_mobile_permalink');
		add_filter('the_content_more_link','clf_base_mobile_permalink');
		add_filter('year_link','clf_base_mobile_permalink');
		
		remove_action("wp_head",'_admin_bar_bump_cb'); // removed the admin var
		// add_filter('next_post_link','clf_base_mobile_permalink');
		// add_filter('term_link','clf_base_mobile_permalink');		
	endif; // end of preview being shown
	
	
	
	add_action('the_content', 'clf_base_mobile_the_content',1);
	add_action('the_content', 'clf_base_transcode_mobile_the_content',2);
	
	// add meta data to the site - mobile html5 boilerplate 
	add_action("wp_head",'clf_base_mobile_head');
	// deregister 
	if(!is_admin()):
		
		wp_enqueue_script( 'clf-base-mobile', get_bloginfo('stylesheet_directory').'/library/mobile/js/mobile.js', array('jquery') );
		
	endif;

}
// we are still using the mobile browser
// show html when you are showing site to a mobile browser 
// not the mobile view 
// the user has selected to see the regular site 
if( clf_base_is_mobile_browser() && !clf_base_display_mobile_view() ):
	
	add_action('the_content', 'clf_base_transcode_mobile_the_content',2 );
	if( clf_base_mobile_view_enabled() )
	add_action("hybrid_after_html",'clf_base_mobile_show_switch_to_mobile' );
	
endif; // end of making the content more mobile make the content more mobile frienldy

/** 
 * Regular init function will be executed everytime 
 */
function clf_base_init_mobile(){
	
	// create the mobile widget area
	register_sidebar( 
		array( 'name' => __('Mobile', 'hybrid'), 
		'id' => 'mobile-widget', 
		'description'   => 'Widget area that appears on the mobile side at the bottom of the content',
		'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 
		'after_widget' => '</div></div>', 
		'before_title' => '<h3 class="widget-title">', 
		'after_title' => '</h3>' ) );
		// only some widgets should be displayed 
		
	// create a menu area for mobile
	register_nav_menu( 'mobile-menu', __( 'Mobile Menu' ) );
	
}
/*
 Function is run on init when you are showing the mobile site to a mobile browser
 */
function clf_base_is_mobile(){
	
	// replace the stylesheet with the mobile one!
	add_filter( "stylesheet_uri", 'clf_base_mobile_stylesheet_uri_filter');
	
	if( current_theme_supports( 'clf' ) ):
	
		add_action( "hybrid_before_html","clf_base_mobile_header_html");
		add_action( "hybrid_after_html","clf_base_mobile_footer_html");
	
	endif;
	
	add_action( "hybrid_header",'clf_base_mobile_nav' ,20);
	add_action( "hybrid_header",'clf_base_page_mobile_nav',20);
	
	// widgets 
	if( is_active_sidebar('mobile-widget') )
		add_filter( 'sidebars_widgets', 'clf_base_mobile_remove_sidebars' );
	
	add_action("hybrid_after_container", 'clf_base_show_mobile_widget');
	
	// remove navigation
	remove_action( "hybrid_after_header", 'clf_base_page_nav' );
	
	// remove breadcrumbs
	remove_action( 'hybrid_after_header','hybrid_breadcrumb',14);
	
	if( $clf_base_options['navigation']['breadcrumbs']['enable'] )
		add_action( 'clf-base-navigation-shell','hybrid_breadcrumb',14);
		
	add_action( 'clf-base-navigation-shell','clf_base_mobile_search',10);
	add_filter('hybrid_body_class', 'clf_base_mobile_body_class');
	
	// remove the admin bar when you are doing the preview
	if( clf_base_display_mobile_preview() ):
		add_filter('show_admin_bar', '__return_false');
		remove_action('wp_head', '_admin_bar_bump_cb');
	endif;
	
	// convert all the tabs into accordians
	// shortcode
	remove_shortcode( 'tabs' );
	remove_shortcode('tab');
	add_shortcode('tab', 'olt_display_shortcode_accordion'); // Individual accordion
    add_shortcode('tabs', 'olt_display_shortcode_accordions'); // The shell
	// wiki embed
	add_filter( 'wikiembed_override_atts', 'clf_base_wiki_embed_mobile_attr_override'); 
	
	// section widget
	// todo
		
	//wp_deregister_script('jquery');
	wp_deregister_script( 'clf-base-cwl-google' );
	wp_deregister_script( 'clf-base-cwl' );
	wp_deregister_script( 'clf-base-navigation' );
	wp_deregister_script( 'wordpress-admin-bar' );
	wp_deregister_script( 'clf-base-spotlight' ); // we are using the reguar stuff here
	
	// mobile spotlight
	add_filter("clf_base_sportlight_attr","clf_base_mobile_spotlight_filter");
	// we need to diregister many styles
	wp_deregister_style( 'ie7-style' );
	wp_deregister_style( 'wordpress-admin-bar' );
	
	
	// remove normal clf 
	remove_action("hybrid_before_html","clf_base_clf_header_html");
	remove_action("hybrid_after_html","clf_base_clf_footer_html");
	remove_action('hybrid_head','clf_base_add_print_stylesheet');
	
}
/**
 * clf_base_mobile_body_class function.
 * 
 * @access public
 * @param mixed $body_class
 * @return void
 */
function clf_base_mobile_body_class( $body_class ) {

	return $body_class. " is-mobile";
}

function clf_base_wiki_embed_mobile_attr_override( $atts ) {
	

	if( in_array( "tabs", $atts ) ):
		global $wikiembed_content_count;
		 
		foreach($atts as $key=>$value):
			if($value == 'tabs')
				$new_atts[$key] = 'accordion';
			else
				$new_atts[$key] = $value;
				
		endforeach;
			
		return $new_atts;
		
	endif;
		
	return $atts;
}
/*
function clf_base_mobile_page(){
	global $post;
	if(is_page() && isset($post->post_parent) && $post->post_parent != 0):
	
	
		echo '<div class="nav">'.clf_base_childpages_shortcode().'</div>';
	endif;

}
*/
/**
 * clf_base_display_mobile_view function.
 * Tells us if we should display the mobile site
 * @access public
 * @return void
 */
function clf_base_display_mobile_view()
{
	global $clf_base_options;
	// check for the cookie 
	if( isset( $_GET['fullsite'] ) )
		clf_base_mobile_set_fullsite();
	
	if(clf_base_display_mobile_preview())
		return true;
	// check the browser 
	$mobile_device = clf_base_mobile_detect_mobile_device();
	
	if( ( $mobile_device['type'] != '0')  && clf_base_mobile_view_enabled() ):
		return true;
		
	else:
		return false;
	endif;
}
/**
 * clf_base_is_mobile_browser function.
 * tells us if we are using the mobile brower true or false
 * @access public
 * @return void
 */
function clf_base_is_mobile_browser() {
	$mobile_device = clf_base_mobile_detect_mobile_device();
	if( clf_base_display_mobile_preview() || $mobile_device['status'] ):
		return true;
	else:
		return false;
	endif;


}
function clf_base_display_mobile_preview() {
	return isset( $_GET['mobile'] );
}

function clf_base_mobile_view_enabled() {
	global $clf_base_options;
	return isset( $clf_base_options['mobile']['view']['enable'] );
}


function clf_base_mobile_search(){
	?>
	<div class="mobile-search"><?php get_search_form(); ?></div>
	<?php
	
}
/**
 * clf_base_mobile_stylesheet_uri_filter function.
 * Replaces the current filter with the mobile css
 * @access public
 * @return void
 */
function clf_base_mobile_stylesheet_uri_filter()
{
	global $clf_base_options;
	$wp_site_upload_directory = wp_upload_dir();
	
	//return get_bloginfo('stylesheet_directory').'/mobile.css';
	return $wp_site_upload_directory ['baseurl'].'/clf_base/css/'.$clf_base_options['style']['mobile-mini'];

}
function clf_base_mobile_head()
{ 
	global $clf_base_options;
	?>
	<!-- Mobile viewport optimization http://goo.gl/b9SaQ -->
	<meta name="HandheldFriendly" content="True">
	<meta name="MobileOptimized" content="320"/>
	<meta name="viewport" content="width=device-width, target-densitydpi=160dpi, minimum-scale=1.0, maximum-scale=1.0, user-scalable=no" />
	<meta http-equiv="cleartype" content="on" />
	<?php /*
	<!-- Home screen icon  Mathias Bynens http://goo.gl/6nVq0 -->
	<!-- For iPhone 4 with high-resolution Retina display: -->
	<link rel="apple-touch-icon-precomposed" sizes="114x114" href="img/h/apple-touch-icon.png" />
	<!-- For first-generation iPad: -->
	
	<link rel="apple-touch-icon-precomposed" sizes="72x72" href="img/m/apple-touch-icon.png" />
	<!-- For non-Retina iPhone, iPod Touch, and Android 2.1+ devices: -->
	<link rel="apple-touch-icon-precomposed" href="img/l/apple-touch-icon-precomposed.png" />
	<!-- For nokia devices: -->
	<link rel="shortcut icon" href="img/l/apple-touch-icon.png" />
	
	<!-- Mobile IE allows us to activate ClearType technology for smoothing fonts for easy reading -->
	*/
	?>
	

	<?php
}
/**
 * clf_base_mobile_header_html function.
 * Replace the current header html with a mobile friendly version
 * @access public
 * @return void
 */
function clf_base_mobile_header_html() {
	
	global $clf_base_options;
	require_once("html/header.php");
}
/**
 * clf_base_mobile_footer_html function.
 * Replace the current footer html with a mobile friendly version
 * @access public
 * @return void
 */
function clf_base_mobile_footer_html() {

	global $clf_base_options;
	require_once("html/footer.php");
}
/**
 * clf_base_mobile_show_switch_to_mobile function.
 * 
 * @access public
 * @return void
 */
function clf_base_mobile_show_switch_to_mobile() {
	echo "<div class='mobile-footer'><a href='?switch-to-mobile=true' class='button'>Switch to mobile</a></div>";
}


/**
 * Widgets 
 */
 
/**
 * clf_base_get_mobile_widget function.
 * 
 * @access public
 * @return void
 */
function clf_base_show_mobile_widget(){ 
	get_sidebar( 'mobile' ); 
}
function clf_base_mobile_remove_sidebars($sidebars_widgets){
	// remove widget area if mobile widget are is active

	unset($sidebars_widgets['primary']); 
	unset($sidebars_widgets['secondary']);
	unset($sidebars_widgets['subsidiary']);
	unset($sidebars_widgets['frontpage-widget']);

	return $sidebars_widgets;
}

/**
 * Filters 
 */
/**
 * clf_base_mobile_permalink function.
 * 
 * @access public
 * @param mixed $permalink
 * @return void
 */
function clf_base_mobile_permalink($permalink)
{
	$search = array(
		"/?mobile=true/", 
		"/?mobile=true", 
		"?mobile=true", 
		"//?mobile=true");
		
	$permalink = str_replace($search, "", $permalink);
	
	return $permalink."?mobile=true";
}

/**
 * Content 
 */
/**
 * clf_base_mobile_the_content function.
 * 
 * @access public
 * @param mixed $content
 * @return void
 */
function clf_base_mobile_the_content($content) {
	global $post;
	$custom = get_post_meta($post->ID, 'custom-mobile-content');
	
	if($custom)
		return $custom[0];
	
	return $content;
}
/**
 * clf_base_transcode_mobile_the_content function.
 * 
 * @access public
 * @param mixed $content
 * @return void
 */
function clf_base_transcode_mobile_the_content($content)
{
	return clf_base_transcoder_remove_media($content);
}


function clf_base_mobile_spotlight_filter($atts) {
	$atts['lookandfeel'] = 'mobile';
	$atts['width'] = 300;
	$atts['height'] = 175;
	return $atts;
}

/* Mobile Nav */
/**
 * clf_base_page_mobile_nav function.
 * Function that sets the mobile navigation
 * @access public
 * @return void
 */
function clf_base_page_mobile_nav()
{
	global $clf_base_options;
	?>
	<div id="navigation-shell">
	<?php 
	do_action('clf-base-navigation-shell');
	if(has_nav_menu( 'mobile-menu' )): ?>
		<div id="navigation">
		<?php 
		$args = array( 
		'theme_location'  => 'mobile-menu', 
		'container_class' => ' page-nav '.$clf_base_options['navigation']['style'].' '.$clf_base_options['navigation']['dropdown']['type'] ,
		'echo'			  => 0 , 
		
		);
		if(isset($clf_base_options['navigation']['dropdown']['page-caption']['enable']))
			$args['walker'] =  new Caption_Walker_Menu();
		$nav = wp_nav_menu( $args );
		
		$nav = str_replace( '<div class="', '<div id="menu-top-menu" class="', $nav );
		$nav = str_replace( '<ul id="menu-top-menu" class="menu">', '<ul>', $nav );
		echo preg_replace( '/<ul>/', '<ul class="menu sf-menu ">', $nav, 1 );
		
		?>
		</div>

	<?php 
	else:
		clf_base_page_nav();
	endif;
	?>
	</div>
	<?php

}
/**
 * clf_base_mobile_nav function.
 * Enables tha tabs 
 * @access public
 * @return void
 */
function clf_base_mobile_nav(){
	?>
	<a id="navigation-link" href="#navigation">Menu</a>
	<?php
}