<?php 
/** 
 * Mobile
 *
 */
global $clf_base_options; // load the back end
add_action('admin_init', 'clf_base_mobile');

add_action('wp_ajax_add_mobile_icon', 'clf_base_mobile_icon' );
add_filter('clf_base_theme_options_validate','clf_base_generate_mobile_styles',2);


add_filter("clf_base_modify_style_css_content",'clf_base_modify_clf_header_mobile_colours');
/**
 * clf_base_frontpage function.
 * 
 * @access public
 * @return void
 */
function clf_base_mobile() {
	add_settings_section('mobile', 'Mobile <span>(beta)</span>', 'clf_base_theme_options_mobile', 'clf-base-theme-options');
	add_settings_field('clf-base-mobile-enable', 'Mobile', 'clf_base_theme_options_mobile_enable', 'clf-base-theme-options', 'mobile');
	add_settings_field('clf-base-mobile-content-enable', 'Mobile Content','clf_base_theme_options_mobile_content_enable', 'clf-base-theme-options', 'mobile');
	// add_settings_field('clf-base-mobile-icon', 'Mobile Icon','clf_base_theme_options_mobile_icon', 'clf-base-theme-options', 'mobile');
	add_settings_field('clf-base-mobile-preview', 'Mobile Preview', 'clf_base_theme_options_mobile_preview', 'clf-base-theme-options', 'mobile');
	
	wp_register_style('clf-base-css-ui-mobile', get_bloginfo('stylesheet_directory').'/library/mobile/panel.css');
	
	add_action('clf_base_admin_ui','clf_base_mobile_styles');

}

function clf_base_mobile_styles() {
	wp_enqueue_style('clf-base-css-ui-mobile');
	
	// mobile_content for the Look & Feel
	//wp_enqueue_script('clf-base-fonts-and-colors-panel', get_bloginfo('stylesheet_directory').'/library/fonts-and-colors/panel.js', array('jquery'));
}

/**
 * clf_base_theme_options_mobile function.
 * Place holder function 
 * @access public
 * @return void
 */
function clf_base_theme_options_mobile()
{
	
}

function clf_base_theme_options_mobile_enable(){
	global $clf_base_options;
	?>
	
	<div class="explanation">
		<h3><label><input type="checkbox" id="mobile_view_enable" name="clf_base[mobile][view][enable]" value="1" <?php checked( isset( $clf_base_options['mobile']['view']['enable'] ) ); ?>/> Enable Mobile View</label></h3>
		<p>by enabling the mobile view your site will be optimized for the mobile phone</p>
	</div>
	<?php
	
}

function clf_base_theme_options_mobile_content_enable(){
	global $clf_base_options;
	?>
	<div class="explanation">
		<h3><label><input type="checkbox" id="navigation_top_enable" name="clf_base[mobile][content][enable]" value="1" <?php checked( isset( $clf_base_options['mobile']['content']['enable']) ); ?>/> Enable Mobile Content</label></h3>
		<p>by enabling the mobile content you have the option to overwrite post and page content with a mobile friendlier version.</p>
	</div>
	<?php
	
}

function clf_base_theme_options_mobile_icon() {
	global $clf_base_options;
	?>
	
	<div>
		<div class="explanation">
		<h3><label><input type="checkbox" name="clf_base[mobile][icon][enable]" value="1" <?php checked(isset( $clf_base_options['mobile']['icon']['enable'])); ?>/> Add a site icon for mobile bookmarks </label></h3>
		
		<p>Enable the mobile icon feature.  This feature allows you to specify an image as a mobile icon, it appears as a when you bookmark your site on the home screen.</p>
		
		</div>
		<span><a href='<?php echo admin_url('admin-ajax.php?action=add_mobile_icon&TB_iframe=true&height=600&width=600'); ?>' id='add_icon' class='thickbox button' title='Add a Default Mobile Icon' >Add a Mobile Icon</a></span> The mobile icon should be at least 144px in width and 144px in height. <br />
		<br />
		<label><strong>Current Mobile Icon</strong></label>
		<div id="default-mobile-icon">
		<!-- <img src="<?php esc_url(header_image()) ?>" width="55px" alt="default header image" /> -->
		</div>
		
	</div>
	
	
	<?php
}

/**
 * clf_base_theme_options_mobile_preview function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_mobile_preview()
{
	global $clf_base_options;
	
	?>
		<div class="preview-mobile iphone">
		<em>size 320 by 480</em>
		<iframe src="<?php bloginfo('url'); ?>/?mobile" width="320" height="480" style="border:1px solid #CCC;"  ></iframe>
		</div>
		<div class="half"> 
		<p>Scan the QR code with your phone to browse the preview on your mobile device.</p>
		<img src="///chart.googleapis.com/chart?cht=qr&chs=250x250&chl=<?php bloginfo('url'); ?>/?mobile&choe=UTF-8" /></div>
	<?php
}


/**
 * Custom mobile content panel 
 * 
 *-----------------------------------------------------
 **/

if( isset($clf_base_options['mobile']['content']['enable']) ):
	/* Use the admin_menu action to define the custom boxes */
	add_action('admin_menu', 'clf_base_custom_fields_custom_mobile_content_box');
	
	/* Use the save_post action to do something with the data entered */
	add_action('save_post', 'clf_base_custom_fields_custom_mobile_content_box_save');
endif;
/* Adds a custom section to the "advanced" Post and Page edit screens */
function clf_base_custom_fields_custom_mobile_content_box() {
	add_meta_box( 'clf_base_custom_fields_custom_mobile_content_box', __( 'Mobile Content', 'clf_base' ), 'clf_base_custom_fields_custom_mobile_content_box_inner', 'post', 'normal','high' );
	add_meta_box( 'clf_base_custom_fields_custom_mobile_content_box', __( 'Mobile Content', 'clf_base' ), 'clf_base_custom_fields_custom_mobile_content_box_inner', 'page', 'normal','high' );
}

/**
 * clf_base_custom_fields_custom_mobile_content_box_inner function.
 * 
 * @access public
 * @return void
 */
function clf_base_custom_fields_custom_mobile_content_box_inner()
{
   global $post;
  
   $clf_base_permission_a = get_post_meta($post->ID, 'custom-mobile-content');
   $clf_base_mobile_content =  $clf_base_permission_a[0];

   // Use nonce for verification
   echo '<input type="hidden" name="clf_base_custom_fields_custom_mobile_content_noncename" id="clf_base_permissions_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
   // The actual fields for data entry
  ?>
  	<div id="clf_base_custom_mobile_content_box">
  		<?php wp_editor( $clf_base_mobile_content, "clfbasecustommobilecontent", array('textarea_name'=>"clf_base_custom_mobile_content",'teeny'=>true, 'media_buttons'=>true) ); ?>
  	</div>
  	<script type="text/javascript">
  	jQuery('document').ready(function($){
  		$('#clf_base_custom_fields_custom_mobile_content_box').removeClass('postbox');
  		// $('#clf_base_custom_mobile_content_box').closest('.meta-box-sortables').removeClass('meta-box-sortables');
  	});
  	</script>
  	This will only show on the mobile site
  <?php
}

/**
 * clf_base_custom_fields_custom_mobile_content_box_save function.
 * 
 * @access public
 * @param mixed $post_id
 * @return void
 */
function clf_base_custom_fields_custom_mobile_content_box_save($post_id)
{
	if ( !wp_verify_nonce( $_POST['clf_base_custom_fields_custom_mobile_content_noncename'], plugin_basename(__FILE__) )) {
			return $post_id;
	}
	
	// verify if this is an auto save routine. If it is our form has not been submitted, so we dont want
	// to do anything
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
	return $post_id;
	
	$data = $_POST['clf_base_custom_mobile_content'];
	
	// Do something with $mydata 
	// probably using add_post_meta(), update_post_meta(), or 
	// a custom table (see Further Reading section below)
	
	if(get_post_meta($post_id, 'custom-mobile-content') == "")  
		add_post_meta($post_id, 'custom-mobile-content', $data, true);  
	
	elseif($data != get_post_meta($post_id, 'custom-mobile-content', true))  
		update_post_meta($post_id, 'custom-mobile-content', $data);
	 
	return $post_id;
}


function clf_base_mobile_icon()
{
	require_once("icons/add-icons.php");
	exit;
}


function clf_base_generate_mobile_styles( $options )
{
	global $clf_base_options;
	$clf_base_options = $options;
	$style_paths = array();
	
	// start from the mobile styles sheets 
	$style_paths = apply_filters( 'clf_base_add_editor_style_path', $style_paths);
	// remove style.css
	$style = array_pop ( $style_paths);
	$style_paths[] = "/mobile.css";
	
	// go though all the urls and extract all the css out of them
	foreach($style_paths as $file):
		$css_content .= "/* $file */";
		$css_content .= @file_get_contents(STYLESHEETPATH. $file );
	endforeach;
	
	$css_content =  apply_filters( 'clf_base_add_style_css_content', $css_content );
	
	$css_content =  apply_filters( 'clf_base_modify_style_css_content', $css_content );
	
	// minify the css 
	$css_content_minify = clf_base_minify_style( $css_content );
	
	// create the file 
	$wp_site_upload_directory = wp_upload_dir();

	
	$style_folder_dir = $wp_site_upload_directory['basedir']."/clf_base/css/";
	
	
	// delete previous files 
	if( file_exists  (  $style_folder_dir )):
		if ( $style_dir = opendir( $style_folder_dir ) ) {
			while ( false !== ( $style_file = readdir($style_dir) ) ) {
				if ( ( preg_match( "/-mobile-/", $style_file ) || preg_match( "/-mobile-dev/", $style_file ) ) && '.' != $style_file && '..' != $style_file )
					@unlink( $style_folder_dir . '/' .  $style_file );
			}
		}
		
		closedir( $style_dir );
	else:
		mkdir( $style_folder_dir );
	endif; 
	
	// create the new files 
	$minified_file = 'clf-base-mobile-'.time().'.css';
	$minified_style_file  = fopen( $style_folder_dir.$minified_file, 'w') or die("can't open file");
	
	
	fwrite($minified_style_file,$css_content_minify);
	fclose($minified_style_file);
	
	$developer_file = 'clf-base-mobile-dev.css';
	$developer_style_file = fopen( $style_folder_dir.$developer_file, 'w') or die("can't open file");
	
	fwrite($developer_style_file,$css_content);
	fclose($developer_style_file);
	
	$clf_base_options['style']['mobile-mini'] 	= $minified_file;
	$clf_base_options['style']['mobile-dev'] 	= $developer_file;
	
	return $clf_base_options;
}

function clf_base_modify_clf_header_mobile_colours($css){

	global $clf_base_options;
	
	switch( $clf_base_options['clf_header']['option'] ){
		case 1:
		
		break;
		case 2:
		
		break;
		case 3:
		
		break;
		case 4:
		
		break;
		case 1:
		
		break;
		case 1:
		
		break;
	
	}
	
	return $css;

}

