<?php
/** 
 * Navigation 
 *
 */
add_action('admin_init', 'clf_base_navigation');


add_filter("clf_base_add_style_path",'clf_base_add_navigation_styles');
/**
 * clf_base_navigation function.
 * 
 * @access public
 * @return void
 */
function clf_base_navigation() {
	// add the section navigation 
	add_settings_section('navigation', 'Navigation', 'clf_base_theme_options_navigation', 'clf-base-theme-options');
	
	add_settings_field('clf-base-navigation-style', 'Style', 'clf_base_theme_options_navigation_style', 'clf-base-theme-options', 'navigation');
	add_settings_field('clf-base-navigation-dropdown', 'Dropdown', 'clf_base_theme_options_navigation_dropdown', 'clf-base-theme-options', 'navigation');
	add_settings_field('clf-base-navigation-breadcrumbs', 'Breadcrumbs', 'clf_base_theme_options_navigation_breadcrumbs', 'clf-base-theme-options', 'navigation');
	add_settings_field('clf-base-navigation-navigation-links', 'Next and Previous Posts', 'clf_base_theme_options_display_navigation_links', 'clf-base-theme-options', 'navigation');
	
	wp_register_style('clf-base-css-ui-navigation', get_bloginfo('stylesheet_directory').'/library/navigation/panel.css');
	
	add_action('clf_base_admin_ui','clf_base_navigation_ui');
	
}

function clf_base_add_navigation_styles($paths)
{
	$paths[] = '/library/navigation/css/navigation.css';
	
	return $paths;
}
/**
 * clf_base_navigation_ui function.
 * 
 * @access public
 * @return void
 */
function clf_base_navigation_ui() {
	wp_enqueue_style( 'clf-base-css-ui-navigation');
	wp_enqueue_script('clf-base-navigation-panel', get_bloginfo('stylesheet_directory').'/library/navigation/panel.js', array('jquery'));
}

/**
 * clf_base_theme_options_navigation function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_navigation() {	
	global $clf_base_options;
	?>
		<div class="explanation">
			<h3>Preview</h3>
			<p>The "Navigation" panel controls the appearance of the horizontal navigation bar.  Experiment with the options below, and see the changes reflected in the preview navigation bar here.</p>
		</div>
		<div id="menu-top-menu" class="<?php echo $clf_base_options['navigation']['style']." ".$clf_base_options['navigation']['dropdown']['type']; ?>">
			<?php include('inc/menu.html'); ?>
		</div>
	<?php 
}

/**
 * clf_base_theme_options_navigation_style function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_navigation_style() {
	global $clf_base_options;
	
	?>
	<div class="explanation">
		<h3><label><input type="checkbox" id="navigation_top_enable" name="clf_base[navigation][top][enable]" value="1" <?php checked( isset( $clf_base_options['navigation']['top']['enable']) ); ?>/> Enable top navigation</label></h3>
		<p>You can choose to disable the top navigation. </p>
	</div>
	Choose between the different navigation styles:

	<div id="navigation-style" class="options-shell">
	<div class="option half">
		<label><input type="radio" name="clf_base[navigation][style]" value="pipes" <?php checked('pipes', $clf_base_options['navigation']['style']); ?>/> Pipes</label>
		
	</div>
	
	<div class="option half clear">
		<label><input type="radio" name="clf_base[navigation][style]" value="plain" <?php checked('plain', $clf_base_options['navigation']['style']); ?>/> Plain</label>
	</div>
	
	<div class="option half clear">
		<label><input type="radio" name="clf_base[navigation][style]" value="tabs" <?php checked('tabs', $clf_base_options['navigation']['style']); ?>/> Tabs</label>
		
	</div>
	
	<div class="option half clear">
		<label><input type="radio" name="clf_base[navigation][style]" value="single-tab" <?php checked('single-tab', $clf_base_options['navigation']['style']); ?>/> Single Tab</label>
		
	</div>
	
	</div>
	<?php

}

/**
 * clf_base_theme_options_navigation_dropdown function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_navigation_dropdown() {
	global $clf_base_options;
	?>
	<div class="explanation">
		<h3><label><input type="checkbox" id="navigation_dropdown_enable" name="clf_base[navigation][dropdown][enable]" value="1" <?php checked( isset($clf_base_options['navigation']['dropdown']['enable'])); ?>/> Enable dropdowns in your navigation</label></h3>
		<p>This option enables the use of dropdown menus in the navigation bar.  Drop-downs allows you to show deeper levels of your page hierarchy.  If drop-downs are disabled, only the top level pages will be shown. This option is ignored if you are using the <a href="nav-menus.php">WordPress Menu builder</a></p>
	</div>
	<div id="dropdown_depth">
		<div class="half options-shell">
			<div class="option half clear"><label><input type="radio" name="clf_base[navigation][dropdown][depth]" value="2" <?php checked('2', $clf_base_options['navigation']['dropdown']['depth']); ?>/> Show secondary level pages.</label></div>
			<div class="option half clear"><label><input type="radio" name="clf_base[navigation][dropdown][depth]" value="3" <?php checked('3', $clf_base_options['navigation']['dropdown']['depth']); ?>/> Show seconday &amp; tertiary level pages.</label></div>
		</div>
		<div class="half">
			<p>Choose how much of your navigation structure you'd like to show on your dropdown.</p>
		</div>
	</div>
	
	<div id="navigation-dropdown" class="options-shell clear">
	<div class="explanation">
		<h3>Choose between the different dropdown types</h3>
		<p>Your selection is immediately reflected in the preview navigation bar at the top of this section.  Experiment with the options to see what they look like.</p>
	</div>
	<div class="option half clear">
		<label><input type="radio" name="clf_base[navigation][dropdown][type]" value="single-dropdown" <?php checked('single-dropdown', $clf_base_options['navigation']['dropdown']['type']); ?>/> Single Column</label> 
		
		<p><input type="checkbox" name="clf_base[navigation][dropdown][superfish][enable]" value="1" <?php checked(isset( $clf_base_options['navigation']['dropdown']['superfish']['enable'])); ?>/> Add arrows</p>
		<p>Drop-down shows all child pages in a list in one single column.</p>
		
	</div>
	

	<div class="option half">
		<label><input type="radio" name="clf_base[navigation][dropdown][type]" value="fullwidth-dropdown" <?php checked('fullwidth-dropdown', $clf_base_options['navigation']['dropdown']['type']); ?>/> Full Width</label>
		<p>Drop-down shows child pages in four columns distributed across the width of the site.</p>
	</div>
	
	</div>
	<div class="explanation  clear">
		<label><input type="checkbox" id="navigation_dropdown_enable" name="clf_base[navigation][dropdown][page-caption][enable]" value="1" <?php checked( isset($clf_base_options['navigation']['dropdown']['page-caption']['enable'])); ?>/> Enable page captions in your navigation</label>
		<p>When using this feature you will be able to add HTML to each dropdown by filling out a custom field. </p>
	</div>
	<?php
}

/**
 * clf_base_theme_options_navigation_breadcrumbs function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_navigation_breadcrumbs() {
	global $clf_base_options;
	?>
	
	<div class="explanation">
		<h3><label><input type="checkbox" name="clf_base[navigation][breadcrumbs][enable]" value="1" <?php checked( isset( $clf_base_options['navigation']['breadcrumbs']['enable'])); ?>/> Display breadcrumbs after your header</label></h3>
		<p>Breadcrumbs show where the current page sits relative to the overall site hierarchy.  Starting at the top level home page, the breadcrumb will list, level by level, the lineage of pages that leads to the current page.</p>
		<p>i.e. <em>UBC &raquo; Faculty of Arts &raquo; Department of English &raquo; ENGL 101</em></p>
		<p>Breadcrumbs are particularly useful for websites with deep hierarchical structure, where they serve as a guide for navigating your site.</p>
	</div>
	<div class="clear segment">
		<label>Before text <br /><input type="text" class="small-text" name="clf_base[navigation][breadcrumbs][before]" value="<?php echo $clf_base_options['navigation']['breadcrumbs']['before']; ?>" /> </label>
	</div>
	<div class="segment">
		<label>Home Text <br /><input type="text" class="small-text" name="clf_base[navigation][breadcrumbs][show_home]" value="<?php echo $clf_base_options['navigation']['breadcrumbs']['show_home']; ?>" /> </label>
	</div>
	<div class="segment">
		<label>Separator <br /><input type="text" class="small-text" name="clf_base[navigation][breadcrumbs][separator]" value="<?php echo $clf_base_options['navigation']['breadcrumbs']['separator']; ?>" /> </label>
	</div>
	<div class="segment">
		Child Page<br />
		<a href="#">Child Page</a>
	</div>
	<div class="segment">
		<label>After text <br /><input type="text" class="small-text" name="clf_base[navigation][breadcrumbs][after]" value="<?php echo $clf_base_options['navigation']['breadcrumbs']['after']; ?>" /></label>
	<?php 
}

/**
 * clf_base_theme_options_display_navigation_links function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_display_navigation_links() {
	global $clf_base_options;
	?>
	<div class="explanation">
		<h3><label><input type="checkbox"  name="clf_base[navigation][navigation-links][enable]" value="1" <?php checked(isset($clf_base_options['navigation']['navigation-links']['enable'])); ?> /> Display previous and next post navigation</label></h3>
		<p>Previous and next post navigation allows users to easily move from one post to the next in a series of posts.  This is especially useful for blogs or news websites where there is a long series of entries to navigate through.</p>
	</div>
	Customized the wording in your previous and next post navigation:
	<div id="navigation_links" class="options-shell">
	<div class="half option clear">
		<label><input type="radio" alt=" &laquo; Previous Post | Next Post &raquo;" name="clf_base[navigation][navigation-links][type]" value="next" <?php checked('next', $clf_base_options['navigation']['navigation-links']['type']); ?>/> &laquo; Previous Post | Next Post &raquo;</label>
	</div>
	<div class="half option clear">
		<label><input type="radio" alt="&laquo; Go Back in Time | Go Forward in Time &raquo;" name="clf_base[navigation][navigation-links][type]" value="history" <?php checked('history', $clf_base_options['navigation']['navigation-links']['type']); ?>/> &laquo; Go Back in Time | Go Forward in Time &raquo;</label>
	</div>
	<div class="half option clear">
		<label><input type="radio" alt="&laquo; %title | %title &raquo;"  name="clf_base[navigation][navigation-links][type]" value="link" <?php checked('link', $clf_base_options['navigation']['navigation-links']['type']); ?>/> &laquo; Previous Sample Post | Next Sample Post &raquo;</label>
	</div>
	
		
	</div>
	
	<div class="half clear">
	
		<label>Previous Post Text <input type="text" class="text" id="navigation_links_previous" name="clf_base[navigation][navigation-links][previous]" value="<?php echo $clf_base_options['navigation']['navigation-links']['previous']; ?>" /> </label>
	</div>
	<div class="half">
		<label>Next Post Text<input type="text" class="text" id="navigation_links_next" name="clf_base[navigation][navigation-links][next]" value="<?php echo $clf_base_options['navigation']['navigation-links']['next']; ?>" /> </label>
		
	</div>
	<?php
}



/**
 * Page caption custom field
 *
 */
 if( isset($clf_base_options['navigation']['dropdown']['page-caption']['enable']) ) :
	/* Use the admin_menu action to define the custom boxes */
	add_action('admin_menu', 'clf_base_custom_fields_page_caption_box');
	
	/* Use the save_post action to do something with the data entered */
	add_action('save_post', 'clf_base_custom_fields_page_caption_box_save');
endif;

/* Adds a custom section to the "advanced" Post and Page edit screens */
function clf_base_custom_fields_page_caption_box() {
	add_meta_box( 'clf_base_custom_fields_page_caption_box', __( 'Menu Page Caption', 'clf_base' ), 'clf_base_custom_fields_page_caption_box_inner', 'page', 'advanced','low' );
}


function clf_base_custom_fields_page_caption_box_inner()
{
   global $post;
  
   $clf_base_permission_a = get_post_meta($post->ID, 'page-caption');
   $clf_base_permission =  $clf_base_permission_a[0];

   // Use nonce for verification
   echo '<input type="hidden" name="clf_base_custom_fields_page_caption_noncename" id="clf_base_permissions_noncename_page_caption" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
   // The actual fields for data entry
  ?><div id="clf_base_custom_css_box">
  	
  	<textarea name="clf_base_page_caption" style="width:100%;resize:vertical;"><?php echo $clf_base_permission; ?></textarea>
  	
  	</div>
  <?php

}


function clf_base_custom_fields_page_caption_box_save($post_id)
{
	if ( !wp_verify_nonce( $_POST['clf_base_custom_fields_page_caption_noncename'], plugin_basename(__FILE__) )) {
			return $post_id;
	}
	
	// verify if this is an auto save routine. If it is our form has not been submitted, so we dont want
	// to do anything
	if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
	return $post_id;
	
	
	$data = $_POST['clf_base_page_caption'];
	
	// Do something with $mydata 
	// probably using add_post_meta(), update_post_meta(), or 
	// a custom table (see Further Reading section below)
	
	if(get_post_meta($post_id, 'page-caption') == "")  
		add_post_meta($post_id, 'page-caption', $data, true);  
	
	elseif($data != get_post_meta($post_id, 'page-caption', true))  
		update_post_meta($post_id, 'page-caption', $data);
	
	return $post_id;
}
 
 
 
 